Version 2.42-rc2 · Senast uppdaterad hos TP: 2026-09-14 · Översättare: Daniel Nylander
Hela filen har kontrollerats med l10n-lint. AI-språkgranskningen är ett dokumenterat stickprov och en riktad kontroll av utvalda fynd, inte en fullständig genomläsning. Lint-träffar är inte bekräftade fel.
Språkgranskning och rättelser
Inga rättelser har gjorts efter det dokumenterade stickprovet. Detta betyder inte att hela översättningen är felfri. PO-filen är byteidentisk med originalet och diffen är tom.
Granskade stickprov: 5 meddelanden
Fördelade över filens början, mellanpartier och slut bland översatta, icke-fuzzy meddelanden med kort text. Utöver dessa har rättelserna ovan bedömts mot källtexten. Ingen anmärkning i stickprovet är ingen garanti för hela filen.
*--annotate*[**=**_when_]*--annotate*[**=**_när_]
PID of the process targeted by the pidfd.PID för den process som pidfd riktar in sig på.
This command deconfigures memory block 10. The block must be offline.Detta kommando avkonfigurerar minnesblock 10. Blocket måste vara frånkopplat.
the network namespacenamnrymden för nätverket
*liblastlog2*(3), *pam.conf*(5), *pam.d*(5), *pam*(8)*liblastlog2*(3), *pam.conf*(5), *pam.d*(5), *pam*(8)
Automatisk kontroll
l10n-lint 1.20.2, standardregler med terminologikontroll. Fuzzy och föråldrade poster kan förekomma i verktygets resultat. Rapporterna nedan återger verktygets bedömning av originalet; även åtgärdade träffar finns kvar för spårbarhet.
msgfmt godkänd Både original och redigerad fil klarar msgfmt --check --check-format. Metadata, fuzzy-markeringar och källtexter har bevarats.
cross-newline-duplicate · 3 träffar
Word 'ENOSYS' duplicated across line break
# fail syscall "fallocate" with ENOSYS
enosys -s fallocate ...
# misslyckas med syscall "fallocate" med ENOSYS enosys -s fallocate ...
Word 'ksoftirqd/0' duplicated across line break
$ ps ax -o comm,psr,pid | grep ksoftirqd/0
ksoftirqd/0 0 14
$ sudo taskset -p 1 14
pid 14's current affinity mask: 1
taskset: failed to set pid 14's affinity: Invalid argument
$ echo $?
1 +$ ps ax -o comm,psr,pid | grep ksoftirqd/0 ksoftirqd/0 0 14 $ sudo taskset -p 1 14 pid 14:s aktuella affinitetsmask: 1 taskset: misslyckades med att ställa in pid 14:s affinitet: Ogiltigt argument $ echo $? 1 +
Word 'mount' duplicated across line break
ifconfig lo 127.0.0.1 up # for portmap
# configure Ethernet or such
portmap # for lockd (implicitly started by mount)
mount -o ro 10.0.0.1:/my_root /mnt
killall portmap # portmap keeps old root busy
cd /mnt
pivot_root . old_root
exec chroot . sh -c 'umount /old_root; exec /sbin/init' \
<dev/console >dev/console 2>&1
ifconfig lo 127.0.0.1 up # för portmap # konfigurera Ethernet eller liknande portmap # för lockd (startas implicit av mount) mount -o ro 10.0.0.1:/my_root /mnt killall portmap # portmap håller den gamla roten upptagen cd /mnt pivot_root . old_root exec chroot . sh -c 'umount /old_root; exec /sbin/init' \ <dev/console >dev/console 2>&1
currency-localization · 3 träffar
Currency format may need localization
copyfilerange original-file even-blocks -r <(seq 0 8192 40960|awk '{print $1"::4096"}')
copyfilerange original-file even-blocks -r <(seq 0 8192 40960|awk '{print $1"::4096"}')
Currency format may need localization
sh -c 'stty -icanon min 1; "$0" "$@"; stty icanon' rename -i from to files
sh -c 'stty -icanon min 1; "$0" "$@"; stty icanon' rename -i from to files
Currency format may need localization
[ "$\{FLOCKER}" != "$0" ] && exec env FLOCKER="$0" flock -en "$0" "$0" "$@" || : [ "$\{FLOCKER}" != "$0" ] && exec env FLOCKER="$0" flock -en "$0" "$0" "$@" || : date-format · 2 träffar
Date format may not be localized
Derived from BSD login 5.40 (5/9/89) by mailto:glad@daimi.dk[Michael Glad] for HP-UX. Ported to Linux 0.12: mailto:poe@daimi.aau.dk[Peter Orbaek]. Rewritten to a PAM-only version by mailto:kzak@redhat.com[Karel Zak]Hämtad från BSD login 5.40 (5/9/89) av mailto:glad@daimi.dk[Michael Glad] för HP-UX. Portad till Linux 0.12: mailto:poe@daimi.aau.dk[Peter Orbaek]. Omskriven till en version för enbart PAM av mailto:kzak@redhat.com[Karel Zak]
Date format may not be localized
The *more* command appeared in 3.0BSD. This man page documents *more* version 5.19 (Berkeley 6/29/88), which is currently in use in the Linux community. Documentation was produced using several other versions of the man page, and extensive inspection of the source code.Kommandot *more* dök upp i 3.0BSD. Denna man-sida dokumenterar *more* version 5.19 (Berkeley 29/6/88), som för närvarande används i Linux-samhället. Dokumentationen togs fram med hjälp av flera andra versioner av man-sidan och omfattande inspektion av källkoden.
domain-terminology · 1 träffar
Music domain terminology: prefer 'notsystem/notrad' over 'personal' (staff (music))
setarch --addr-no-randomize mytestprog
setarch ppc32 rpmbuild --target=ppc --rebuild foo.src.rpm
setarch ppc32 -vL3 rpmbuild --target=ppc --rebuild bar.src.rpm
setarch ppc32 --32bit rpmbuild --target=ppc --rebuild foo.src.rpm
setarch --show
setarch --show=$(cat /proc/9284/personality)
setarch --show --pid 9284
setarch --addr-no-randomize mytestprog setarch ppc32 rpmbuild --target=ppc --rebuild foo.src.rpm setarch ppc32 -vL3 rpmbuild --target=ppc --rebuild bar.src.rpm setarch ppc32 --32bit rpmbuild --target=ppc --rebuild foo.src.rpm setarch --show setarch --show=$(cat /proc/9284/personality) setarch --show --pid 9284
duplicate-words · 5 träffar
Duplicate word: 'för'
helps *lsblk*(1) to not read LABELs for all block device from udevd or libblkid, but read it only for device sda1.hjälper *lsblk*(1) att endast läsa LABEL från udevd eller libblkid för enheten sda1, i stället för för alla blockenheter.
Duplicate word: 'enosys'
# fail syscall "fallocate" with ENOSYS
enosys -s fallocate ...
# misslyckas med syscall "fallocate" med ENOSYS enosys -s fallocate ...
Duplicate word: 'som'
For each hole the offset, end and size in bytes are printed in verbose mode, followed by a summary that gives the total size and percentage of the file that each hole type represents by default. If no offset is specified with *--offset*, the whole file is scanned.För varje hål skrivs startposition, slutposition och storlek i byte ut i utförligt läge, följt av en sammanfattning som som standard anger total storlek och andel av filen för varje håltyp. Om ingen position anges med *--offset* söks hela filen igenom.
Duplicate word: 'den'
Suppose you start with no adjtime file. You issue a *hwclock --set* command to set the Hardware Clock to the true current time. *hwclock* creates the adjtime file and records in it the current time as the last time the clock was calibrated. Five days later, the clock has gained 10 seconds, so you issue a *hwclock --set --update-drift* command to set it back 10 seconds. *hwclock* updates the adjtime file to show the current time as the last time the clock was calibrated, and records 2 seconds per day as the systematic drift rate. 24 hours go by, and then you issue a *hwclock --adjust* command. *hwclock* consults the adjtime file and sees that the clock gains 2 seconds per day when left alone and that it has been left alone for exactly one day. So it subtracts 2 seconds from the Hardware Clock. It then records the current time as the last time the clock was adjusted. Another 24 hours go by and you issue another *hwclock --adjust*. *hwclock* does the same thing: subtracts 2 seconds and updates the adjtime file with the current time as the last time the clock was adjusted.Anta att du börjar med att inte ha någon adjtime-fil. Du ger kommandot *hwclock --set* för att ställa in maskinvaruklockan till den verkliga aktuella tiden. *hwclock* skapar adjtime-filen och registrerar i den den aktuella tiden när klockan senast kalibrerades. Fem dagar senare har klockan gått fram 10 sekunder, så du ger kommandot *hwclock --set --update-drift* för att ställa tillbaka den 10 sekunder. *hwclock* uppdaterar adjtime-filen så att den visar den aktuella tiden som den senaste gången klockan kalibrerades, och registrerar 2 sekunder per dag som den systematiska drifthastigheten. 24 timmar går, och sedan ger du kommandot *hwclock --adjust*. *hwclock* konsulterar adjtime-filen och ser att klockan vinner 2 sekunder per dag när den lämnas i fred och att den har lämnats i fred i exakt en dag. Så den subtraherar 2 sekunder från maskinvaruklockan. Sedan registreras den aktuella tiden som den senaste gången klockan justerades. Ytterligare 24 timmar går och du utfärdar en ny *hwclock --adjust*. *hwclock* gör samma sak: subtraherar 2 sekunder och uppdaterar adjtime-filen med den aktuella tiden då klockan senast justerades.
Duplicate word: 'overlay'
mount -t overlay overlay \
-olowerdir=/lower,upperdir=/upper,workdir=/work /merged
mount -t overlay overlay \ -olowerdir=/lower,upperdir=/upper,workdir=/work /merged
ellipsis · 123 träffar
Use typographic ellipsis (…) instead of three dots (...)
*blockdev* [*-q*] [*-v*] _command_ [_command_...] _device_ [_device_...]*blockdev* [*-q*] [*-v*] _kommando_ [_kommando_...] _enhet_ [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
*blockdev* *--report* [_device_...]*blockdev* *--report* [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
*fdisk* *-l* [_device_...]*fdisk* *-l* [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
All partitioning is driven by device I/O limits (the topology) by default. *fdisk* is able to optimize the disk layout for a 4K-sector size and use an alignment offset on modern devices for MBR and GPT. It is always a good idea to follow *fdisk*'s defaults as the default values (e.g., first and last partition sectors) and partition sizes specified by the {plus}/-<size>{M,G,...} notation are always aligned according to the device properties.All partitionering styrs som standard av enhetens I/O-gränser (topologin). *fdisk* kan optimera disklayouten för en 4K-sektorstorlek och använda en inriktningsoffset på moderna enheter för MBR och GPT. Det är alltid en bra idé att följa *fdisk*:s standardvärden eftersom standardvärdena (t.ex. första och sista partitionssektorerna) och partitionsstorlekar som anges med notationen {plus}/-<size>{M,G,...} alltid är inriktade enligt enhetens egenskaper.Use typographic ellipsis (…) instead of three dots (...)
The "last sector" dialog accepts partition size specified by number of sectors or by {plus}/-<size>{K,B,M,G,...} notation.Dialogrutan "last sector" accepterar partitionsstorlek som anges med antal sektorer eller med {plus}/-<size>{K,B,M,G,...} notation.Use typographic ellipsis (…) instead of three dots (...)
The relative sizes if specified with multiplicative suffixes (e.g. +100MiB) are always aligned according to device I/O limits. The {plus}/-<size>{K,B,M,G,...} notation is recommended.De relativa storlekarna, om de anges med multiplikativa suffix (t.ex. +100MiB), justeras alltid i enlighet med enhetens I/O-gränser. Notationen {plus}/-<size>{K,B,M,G,...} rekommenderas.Use typographic ellipsis (…) instead of three dots (...)
*fsck* [*-lsAVRTMNP*] [*-r* [_fd_]] [*-C* [_fd_]] [*-t* _fstype_] [_filesystem_...] [*--*] [_fs-specific-options_]*fsck* [*-lsAVRTMNP*] [*-r* [_fd_]] [*-C* [_fd_]] [*-t* _fstype_] [_filsystem_...] [*--*] [_fs-specific-options_]
Use typographic ellipsis (…) instead of three dots (...)
*fsck* does not check stacked devices (RAIDs, dm-crypt, ...) in parallel with any other device. See below for *FSCK_FORCE_ALL_PARALLEL* setting. The _/sys_ filesystem is used to determine dependencies between devices.*fsck* kontrollerar inte staplade enheter (RAID, dm-crypt, ...) parallellt med någon annan enhet. Se nedan för inställningen *FSCK_FORCE_ALL_PARALLEL*. Filsystemet _/sys_ används för att bestämma beroenden mellan enheter.
Use typographic ellipsis (…) instead of three dots (...)
However, *mkswap* refuses to erase the first block on a device with a disk label (SUN, BSD, ...).*mkswap* vägrar dock att radera det första blocket på en enhet med en disketikett (SUN, BSD, ...).
Use typographic ellipsis (…) instead of three dots (...)
*-A*, *--activate* __device__ [__partition-number__...]*-A*, *--activate* __enhet__ [__partition-number__...]
Use typographic ellipsis (…) instead of three dots (...)
*--delete* _device_ [__partition-number__...]*--delete* _enhet_ [__partition-number__...]
Use typographic ellipsis (…) instead of three dots (...)
*-g*, *--show-geometry* [__device__...]*-g*, *--show-geometry* [__enhet__...]
Use typographic ellipsis (…) instead of three dots (...)
*-l*, *--list* [__device__...]*-l*, *--list* [__enhet__...]
Use typographic ellipsis (…) instead of three dots (...)
*-F*, *--list-free* [__device__...]*-F*, *--list-free* [__enhet__...]
Use typographic ellipsis (…) instead of three dots (...)
*-s*, *--show-size* [__device__...]*-s*, *--show-size* [__enhet__...]
Use typographic ellipsis (…) instead of three dots (...)
*-V*, *--verify* [__device__...]*-V*, *--verify* [__enhet__...]
Use typographic ellipsis (…) instead of three dots (...)
[_device_ *:*] _name_[**=**__value__], ...[_enhet_ *:*] _namn_[**=**__värde__], ...
Use typographic ellipsis (…) instead of three dots (...)
UUID_SUB - pool member UUID or device item UUID, etc. (e.g., zfs, btrfs, ...)UUID_SUB - UUID för poolmedlem eller UUID för enhetsobjekt etc. (t.ex. zfs, btrfs, ...)
Use typographic ellipsis (…) instead of three dots (...)
*last* [options] [_username_|_tty_]...*last* [flaggor] [_användarnamn_|_tty_]...
Use typographic ellipsis (…) instead of three dots (...)
*lastb* [options] [_username_|_tty_]...*lastb* [flaggor] [_användarnamn_|_tty_]...
Use typographic ellipsis (…) instead of three dots (...)
*runuser* [options] *-u* _user_ [[--] _command_ [_argument_...]]*runuser* [flaggor] *-u* _användare_ [[--] _kommando_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*runuser* [options] [*-*] [_user_ [_argument_...]]*runuser* [flaggor] [*-*] [_användare_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*su* [options] [*-*] [_user_|_UID_ [_argument_...]]*su* [flaggor] [*-*] [_användare_|_UID_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*blkid* [*--no-encoding* *--garbage-collect* *--list-one* *--cache-file* _file_] [*--output* _format_] [*--match-tag* _tag_] [*--match-token* _NAME=value_] [_device_...]*blkid* [*--no-encoding* *--garbage-collect* *--list-one* *--cache-file* _fil_] [*--output* _format_] [*--match-tag* _tagg_] [*--match-token* _NAME=value_] [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
*blkid* *--probe* [*--offset* _offset_] [*--output* _format_] [*--size* _size_] [*--match-tag* _tag_] [*--match-types* _list_] [*--usages* _list_] [*--no-part-details*] _device_...*blkid* *--probe* [*--offset* _offset_] [*--output* _format_] [*--size* _storlek_] [*--match-tag* _tagg_] [*--match-types* _lista_] [*--usages* _lista_] [*--no-part-details*] _enhet_...
Use typographic ellipsis (…) instead of three dots (...)
*blkid* *--info* [*--output format*] [*--match-tag* _tag_] _device_...*blkid* *--info* [*--output format*] [*--match-tag* _tagg_] _enhet_...
Use typographic ellipsis (…) instead of three dots (...)
*copyfilerange* [options] _source_ _destination_ _range_...*copyfilerange* [flaggor] _källa_ _mål_ _intervall_...
Use typographic ellipsis (…) instead of three dots (...)
# fail syscall "fallocate" with ENOSYS
enosys -s fallocate ...
# misslyckas med syscall "fallocate" med ENOSYS enosys -s fallocate ...
Use typographic ellipsis (…) instead of three dots (...)
# fail syscall "fallocate" with ENOMEM
enosys -s fallocate:ENOMEM ...
# misslyckas med syscall "fallocate" med ENOMEM enosys -s fallocate:ENOMEM ...
Use typographic ellipsis (…) instead of three dots (...)
# fail syscall "fallocate" with value 12/ENOMEM
enosys -s fallocate:12 ...
# misslyckas med syscall "fallocate" med värdet 12/ENOMEM enosys -s fallocate:12 ...
Use typographic ellipsis (…) instead of three dots (...)
# fail ioctl FIOCLEX with ENOTTY
enosys -i FIOCLEX ...
# misslyckas med ioctl FIOCLEX med ENOTTY enosys -i FIOCLEX ...
Use typographic ellipsis (…) instead of three dots (...)
# fail ioctl FIOCLEX with ENOMEM
enosys -i FIOCLEX:ENOMEM ...
# misslyckas med ioctl FIOCLEX med ENOMEM enosys -i FIOCLEX:ENOMEM ...
Use typographic ellipsis (…) instead of three dots (...)
# fail ioctl FIOCLEX with value 12/ENOMEM
enosys -i FIOCLEX:12 ...
# misslyckas med ioctl FIOCLEX med värdet 12/ENOMEM enosys -i FIOCLEX:12 ...
Use typographic ellipsis (…) instead of three dots (...)
*fincore* [options] _file_...*fincore* [flaggor] _fil_...
Use typographic ellipsis (…) instead of three dots (...)
*getino* [*--pidfs*|*--cgroupns*|*--ipcns*|*--netns*|*--mntns*|*--pidns*|*--timens*|*--userns*|*--utsns*] [*--print-pid*|*-p*] _PID_[:inode]...*getino* [*--pidfs*|*--cgroupns*|*--ipcns*|*--netns*|*--mntns*|*--pidns*|*--timens*|*--userns*|*--utsns*] [*--print-pid*|*-p*] _PID_[:inode]...
Use typographic ellipsis (…) instead of three dots (...)
*getino* [*--print-pid*|*-p*] _PID_[:inode]...*getino* [*--print-pid*|*-p*] _PID_[:inode]...
Use typographic ellipsis (…) instead of three dots (...)
*getino* _PID_[:inode]...*getino* _PID_[:inode]...
Use typographic ellipsis (…) instead of three dots (...)
*hardlink* [options] _directory_|_file_...*hardlink* [flaggor] _katalog_|_fil_...
Use typographic ellipsis (…) instead of three dots (...)
*kill* [**-**_signal_|*-s* _signal_|*-p*] [*-q* _value_] [*-a*] [*--timeout* _milliseconds_ _signal_] [*--*] _pid_|_pid_:_pidfd_inode_|_name_...*kill* [**-**_signal_|*-s* _signal_|*-p*] [*-q* _värde_] [*-a*] [*--timeout* _millisekunder_ _signal_] [*--*] _pid_|_pid_:_pidfd_inod_|_namn_...
Use typographic ellipsis (…) instead of three dots (...)
*kill* [**-**_signal_|*-s* _signal_] _pid_|_pid_:_pidfd_inode_...*kill* [**-**_signal_|*-s* _signal_] _pid_|_pid_:_pidfd_inod_...
Use typographic ellipsis (…) instead of three dots (...)
*lsblk* [options] [_device_...]*lsblk* [flaggor] [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
Full path of the lock. If none is found, or there are no permissions to read the path, it will fall back to the device's mountpoint and "..." is appended to the path. The path might be truncated; use *--notruncate* to get the full path.Fullständig sökväg till låset. Om ingen hittas, eller om det inte finns några behörigheter att läsa sökvägen, kommer den att falla tillbaka till enhetens monteringspunkt och "..." läggs till sökvägen. Sökvägen kan vara avkortad; använd *--notruncate* för att få den fullständiga sökvägen.
Use typographic ellipsis (…) instead of three dots (...)
*namei* [options] _pathname_...*namei* [flaggor] _sökvägsnamn_...
Use typographic ellipsis (…) instead of three dots (...)
*pipesz* [options] [*--set* _size_] [--] [_command_ [_argument_...]]*pipesz* [flaggor] [*--set* _storlek_] [--] [_kommando_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*pipesz* *dd* if=_file_ bs=1M | ...*pipesz* *dd* if=_fil_ bs=1M | ...
Use typographic ellipsis (…) instead of three dots (...)
*rename* [options] _substring replacement file_...*rename* [flaggor] _delsträng ersättning fil_...
Use typographic ellipsis (…) instead of three dots (...)
Given the files _foo1_, ..., _foo9_, _foo10_, ..., _foo278_, the commandsMed tanke på filerna _foo1_, ..., _foo9_, _foo10_, ..., _foo278_, kommandona
Use typographic ellipsis (…) instead of three dots (...)
will turn them into _foo001_, ..., _foo009_, _foo010_, ..., _foo278_. Andkommer att göra dem till _foo001_, ..., _foo009_, _foo010_, ..., _foo278_. Och
Use typographic ellipsis (…) instead of three dots (...)
*waitpid* [-v] [*--timeout*|*-t* _seconds_] PID[:inode]...*waitpid* [-v] [*--timeout*|*-t* _sekunder_] PID[:inod]...
Use typographic ellipsis (…) instead of three dots (...)
*whereis* [options] [*-BMS* _directory_... *-f*] _name_...*whereis* [flaggor] [*-BMS* _katalog_... *-f*] _namn_...
Use typographic ellipsis (…) instead of three dots (...)
*wipefs* [options] _device_...*wipefs* [flaggor] _enhet_...
Use typographic ellipsis (…) instead of three dots (...)
*wipefs* [*--backup*] *-o* _offset device_...*wipefs* [*--backup*] *-o* _offset enhet_...
Use typographic ellipsis (…) instead of three dots (...)
*wipefs* [*--backup*] *-a* _device_...*wipefs* [*--backup*] *-a* _enhet_...
Use typographic ellipsis (…) instead of three dots (...)
*chrt* [options] [_priority_] _command_ [_argument_...]*chrt* [flaggor] [_prioritet_] _kommando_ [_argument_...]
Use typographic ellipsis (…) instead of three dots (...)
*{command}* *new* [*-t* _type_] \-- _command_ [_argument_...]*{command}* *new* [*-t* _typ_] \-- _kommando_ [_argument_...]Use typographic ellipsis (…) instead of three dots (...)
*{command}* *copy* [*-s* _pid_] [*-t* _type_] \-- _command_ [_argument_...]*{command}* *copy* [*-s* _pid_] [*-t* _typ_] \-- _kommando_ [_argument_...]Use typographic ellipsis (…) instead of three dots (...)
*{command} new* \-- _command_ [_argument_...]*{command} new* \-- _kommando_ [_argument_...]Use typographic ellipsis (…) instead of three dots (...)
*{command} copy -s* _123_ \-- _command_ [_argument_...]*{command} copy -s* _123_ \-- _kommando_ [_argument_...]Use typographic ellipsis (…) instead of three dots (...)
*ionice* [*-c* _class_] [*-n* _level_] [*-t*] _command_ [argument] ...*ionice* [*-c* _klass_] [*-n* _nivå_] [*-t*] _kommando_ [argument] ...
Use typographic ellipsis (…) instead of three dots (...)
*-p*, *--pid* _PID_...*-p*, *--pid* _PID_...
Use typographic ellipsis (…) instead of three dots (...)
*-P*, *--pgid* _PGID_...*-P*, *--pgid* _PGID_...
Use typographic ellipsis (…) instead of three dots (...)
*-u*, *--uid* _UID_...*-u*, *--uid* _UID_...
Use typographic ellipsis (…) instead of three dots (...)
*taskset* [options] _mask command_ [_argument_...]*taskset* [flaggor] _mask kommando_ [_argument_...]
Use typographic ellipsis (…) instead of three dots (...)
*uclampset* [options] [*-m* _minimum_] [*-M* _maximum_] _command_ [_argument_...]*uclampset* [flaggor] [*-m* _minimum_] [*-M* _maximum_] _kommando_ [_argument_...]
Use typographic ellipsis (…) instead of three dots (...)
*choom* *-n* _number_ [--] _command_ [_argument_ ...]*choom* *-n* _nummer_ [--] _kommando_ [_argument_ ...]
Use typographic ellipsis (…) instead of three dots (...)
(; flock -n 9 || exit 1; # ... commands executed under lock ...; ) 9>/var/lock/mylockfile(; flock -n 9 || exit 1; # ... kommandon utförda under lås ...; ) 9>/var/lock/mylockfile
Use typographic ellipsis (…) instead of three dots (...)
*hwclock* [_function_] [_option_...]*hwclock* [_function_] [_option_...]
Use typographic ellipsis (…) instead of three dots (...)
*ipcrm* [*shm*|*msg*|*sem*] _ID_ ...*ipcrm* [*shm*|*msg*|*sem*] _ID_ ...
Use typographic ellipsis (…) instead of three dots (...)
*-i*, *--iflag* [*-*]_value_...*-i*, *--iflag* [*-*]_värde_...
Use typographic ellipsis (…) instead of three dots (...)
*losetup* *-d* _loopdev_ ...*losetup* *-d* _loopdev_ ...
Use typographic ellipsis (…) instead of three dots (...)
*losetup* *--remove* _loopdev_ ...*losetup* *--remove* _loopenh_ ...
Use typographic ellipsis (…) instead of three dots (...)
*-d*, *--detach* _loopdev_...*-d*, *--detach* _loopdev_...
Use typographic ellipsis (…) instead of three dots (...)
*-O*, *--output* _column_[,_column_]...*-O*, *--output* _column_[,_column_]...
Use typographic ellipsis (…) instead of three dots (...)
*--remove* _loopdev_...*--remove* _loopenh_...
Use typographic ellipsis (…) instead of three dots (...)
# dd if=/dev/zero of=~/file.img bs=1024k count=10
# losetup --find --show ~/file.img
/dev/loop0
# mkfs -t ext2 /dev/loop0
# mount /dev/loop0 /mnt
...
# umount /dev/loop0
# losetup --detach /dev/loop0
# dd if=/dev/zero of=~/file.img bs=1024k count=10 # losetup --find --show ~/file.img /dev/loop0 # mkfs -t ext2 /dev/loop0 # mount /dev/loop0 /mnt ... # umount /dev/loop0 # losetup --detach /dev/loop0
Use typographic ellipsis (…) instead of three dots (...)
Set UID and GID of the root of the filesystem to the UID and GID of the mount point upon the first sync or umount, and then clear this option. Strange...Ställ in UID och GID för roten av filsystemet till UID och GID för monteringspunkten vid första synkroniseringen eller umount, och avmarkera sedan denna flagga. Märkligt...
Use typographic ellipsis (…) instead of three dots (...)
*prlimit* [options] [**--**_resource_[**=**_limits_]] _command_ [_argument_...]*prlimit* [flaggor] [**--**_resource_[**=**_limits_]] _kommando_ [_argument_...]
Use typographic ellipsis (…) instead of three dots (...)
*renice* [*-n*|*--priority*|*--relative*] _priority_ [*-g*|*-p*|*-u*] _identifier_...*renice* [*-n*|*--priority*|*--relative*] _prioritet_ [*-g*|*-p*|*-u*] _identifierare_...
Use typographic ellipsis (…) instead of three dots (...)
*rfkill* [options] [_command_] [_ID_|_type_ ...]*rfkill* [flaggor] [_kommando_] [_ID_|_typ_ ...]
Use typographic ellipsis (…) instead of three dots (...)
*list* [__id__|__type__ ...]*list* [__id__|__typ__ ...]
Use typographic ellipsis (…) instead of three dots (...)
**block** __id__|__type__ [...]**block** __id__|__typ__ [...]
Use typographic ellipsis (…) instead of three dots (...)
**unblock** __id__|__type__ [...]**unblock** __id__|__typ__ [...]
Use typographic ellipsis (…) instead of three dots (...)
**toggle** __id__|__type__ [...]**toggle** __id__|__typ__ [...]
Use typographic ellipsis (…) instead of three dots (...)
Use the specified _device_ instead of *rtc0* as realtime clock. This option is only relevant if your system has more than one RTC. You may specify *rtc1*, *rtc2*, ... here.Använd den angivna _enheten_ i stället för *rtc0* som realtidsklocka. Denna flaggan är endast relevant om ditt system har mer än en RTC. Du kan ange *rtc1*, *rtc2*, ... här.
Use typographic ellipsis (…) instead of three dots (...)
*setarch* [_arch_] [options] [_program_ [_argument_...]]*setarch* [_arch_] [flaggor] [_program_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
_arch_ [options] [_program_ [_argument_...]]_arkitektur_ [flaggor] [_program_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*--groups* _group_...*--groups* _grupp_...
Use typographic ellipsis (…) instead of three dots (...)
*--inh-caps* (*+*|*-*)_cap_...*--inh-caps* (*+*|*-*)_cap_...
Use typographic ellipsis (…) instead of three dots (...)
*--ambient-caps* (*+*|*-*)_cap_...*--ambient-caps* (*+*|*-*)_cap_...
Use typographic ellipsis (…) instead of three dots (...)
*--bounding-set* (*+*|*-*)_cap_...*--bounding-set* (*+*|*-*)_cap_...
Use typographic ellipsis (…) instead of three dots (...)
*--securebits* (**+**|*-*)__securebit__...*--securebits* (**+**|*-*)__securebit__...
Use typographic ellipsis (…) instead of three dots (...)
*swapon* [options] [_specialfile_...]*swapon* [flaggor] [_specialfil_...]
Use typographic ellipsis (…) instead of three dots (...)
*swapoff* [*-va*] [_specialfile_...]*swapoff* [*-va*] [_specialfil_...]
Use typographic ellipsis (…) instead of three dots (...)
*--show*[**=**__column__...]*--show*[**=**__column__...]
Use typographic ellipsis (…) instead of three dots (...)
non-*swapoff*(2) syscall system error (out of memory, ...)non-*swapoff*(2) syscall systemfel (slut på minne, ...)
Use typographic ellipsis (…) instead of three dots (...)
*swapon* automatically detects and rewrites a swap space signature with old software suspend data (e.g., *S1SUSPEND*, *S2SUSPEND*, ...). The problem is that if we don't do it, then we get data corruption the next time an attempt at unsuspending is made.*swapon* upptäcker automatiskt och skriver om en signatur för ett swaputrymme med gamla väntelägesdata för programvara (t.ex. *S1SUSPEND*, *S2SUSPEND*, ...). Problemet är att om vi inte gör det får vi datakorruption nästa gång ett försök till unsuspending görs.
Use typographic ellipsis (…) instead of three dots (...)
*switch_root* _newroot init_ [_arg_...]*switch_root* _newroot init_ [_arg_...]
Use typographic ellipsis (…) instead of three dots (...)
*tunelp* sets several parameters for the /dev/lp__?__ devices, for better performance (or for any performance at all, if your printer won't work without it...) Without parameters, it tells whether the device is using interrupts, and if so, which one. With parameters, it sets the device characteristics accordingly.*tunelp* ställer in flera parametrar för /dev/lp__?__-enheterna, för bättre prestanda (eller för någon prestanda alls, om din skrivare inte fungerar utan den ...) Utan parametrar berättar den om enheten använder avbrott, och i så fall vilket. Med parametrar ställer den in enhetens egenskaper i enlighet med detta.
Use typographic ellipsis (…) instead of three dots (...)
*umount* *-a* [*-dflnrv*] [*-t* _fstype_] [*-O* _option_...]*umount* *-a* [*-dflnrv*] [*-t* _fstype_] [*-O* _option_...]
Use typographic ellipsis (…) instead of three dots (...)
*-O*, *--test-opts* _option_...*-O*, *--test-opts* _option_...
Use typographic ellipsis (…) instead of three dots (...)
*-t*, *--types* _type_...*-t*, *--types* _typ_...
Use typographic ellipsis (…) instead of three dots (...)
*wdctl* [options] [_device_...]*wdctl* [flaggor] [_enhet_...]
Use typographic ellipsis (…) instead of three dots (...)
*zramctl* *-r* _zramdev_...*zramctl* *-r* _zramdev_...
Use typographic ellipsis (…) instead of three dots (...)
*-p*, *--algorithm-params* _parameter_...*-p*, *--algorithm-params* _parameter_...
Use typographic ellipsis (…) instead of three dots (...)
*-r*, *--reset* _zramdev_...*-r*, *--reset* _zramenhet_...
Use typographic ellipsis (…) instead of three dots (...)
# zramctl --find --size 1024M
/dev/zram0
# mkswap /dev/zram0
# swapon /dev/zram0
...
# swapoff /dev/zram0
# zramctl --reset /dev/zram0
# zramctl --find --size 1024M /dev/zram0 # mkswap /dev/zram0 # swapon /dev/zram0 ... # swapoff /dev/zram0 # zramctl --reset /dev/zram0
Use typographic ellipsis (…) instead of three dots (...)
*agetty* [options] _port_ [_baud_rate_...] [_term_]*agetty* [flaggor] _port_ [_baud_rate_...] [_term_]
Use typographic ellipsis (…) instead of three dots (...)
_baud_rate_,..._baud_rate_,...
Use typographic ellipsis (…) instead of three dots (...)
*script* [options] [_file_] [*--* _command_ [_argument_...]]*script* [flaggor] [_fil_] [*--* _kommando_ [_argument_...]]
Use typographic ellipsis (…) instead of three dots (...)
*--clrtabs*[**=**_tab1 tab2 tab3_ ...]*--clrtabs*[**=**_tab1 tab2 tab3_ ...]
Use typographic ellipsis (…) instead of three dots (...)
*--tabs*[**=**_tab1 tab2 tab3_ ...]*--tabs*[**=**_tab1 tab2 tab3_ ...]
Use typographic ellipsis (…) instead of three dots (...)
Message from yourname@yourhost on yourtty at hh:mm ...
Meddelande från yourname@yourhost på yourtty kl. hh:mm ...
Use typographic ellipsis (…) instead of three dots (...)
*colcrt* [options] [_file_ ...]*colcrt* [flaggor] [_fil_ ...]
Use typographic ellipsis (…) instead of three dots (...)
*column* [options] [_file_ ...]*column* [flaggor] [_fil_ ...]
Use typographic ellipsis (…) instead of three dots (...)
The argument _columns_, for the **--table-*** options below, is a comma-separated list of user-supplied names defined with *--table-columns* _name1_**,**_name2_**,**..., or indices of columns as they appear in the input, beginning with 1, or names defined through a *--table-column* attribute. It's possible to mix names and indices. The special placeholder '0' (e.g. -R0) may be used to specify all columns and '-1' (e.g. -R -1) to specify the last visible column. It's possible to use ranges like '1-5' when addressing columns by indices.Argumentet _kolumner_ för **--table-***-flaggorna nedan är en kommaseparerad lista över användarvalda namn definierade med *--table-columns* _namn1_**,**_namn2_**,**..., kolumnindex enligt ordningen i indata med början på 1, eller namn definierade med ett *--table-column*-attribut. Namn och index kan blandas. Specialvärdet ”0” (t.ex. -R0) kan användas för alla kolumner och ”-1” (t.ex. -R -1) för den sista synliga kolumnen. Intervall som ”1-5” kan användas när kolumner adresseras med index.
Use typographic ellipsis (…) instead of three dots (...)
*hexdump* [options] _file_ ...*hexdump* [flaggor] _fil_ ...
Use typographic ellipsis (…) instead of three dots (...)
*hd* [options] _file_ ...*hd* [flaggor] _fil_ ...
Use typographic ellipsis (…) instead of three dots (...)
*_L[color_unit_1,color_unit_2,...,color_unit_n]**_L[färg_enhet_1,färg_enhet_2,...,färg_enhet_n]*
Use typographic ellipsis (…) instead of three dots (...)
*more* [options] _file_ ...*more* [flaggor] _fil_ ...
Use typographic ellipsis (…) instead of three dots (...)
*pg* *-*_amount_ *-p* _prompt_ *-cefnrs* +line +/pattern/ file_ ...*pg* *-*_mängd_ *-p* _prompt_ *-cefnrs* +line +/pattern/ file_ ...
Use typographic ellipsis (…) instead of three dots (...)
*rev* [option] [_file_...]*rev* [flagga] [_fil_...]
Use typographic ellipsis (…) instead of three dots (...)
*ul* [options] [_file_...]*ul* [flaggor] [_fil_...]
Use typographic ellipsis (…) instead of three dots (...)
*bits* [*-h*] [*-V*] [*-w* _number_] [_mode_] [_mask_|_list_]...*bits* [*-h*] [*-V*] [*-w* _antal_] [_läge_] [_mask_|_lista_]...
end-stop-mismatch · 1 träffar
Translation ends with period but source does not
*last* searches back through the _/var/log/wtmp_ file (or the file given with the *-f* option) and displays a list of all users who logged in (and out) since that file was created. One or more _usernames_ and/or _ttys_ can be given, in which case *last* will show only the entries matching those arguments. (Names of _ttys_ can be abbreviated, thus *last 0* is the same as *last tty0*.)*last* söker tillbaka i filen _/var/log/wtmp_ (eller den fil som anges med flaggan *-f*) och visar en lista över alla användare som loggat in (och ut) sedan filen skapades. Ett eller flera _användarnamn_ och/eller _ttys_ kan anges, och i så fall visar *last* endast de poster som matchar dessa argument. Namnen på _ttys_ kan förkortas, så *last 0* är detsamma som *last tty0*.
false-friends · 1 träffar
False friend: 'actual' should be 'faktisk/verklig', not 'aktuell'
The kernel's timezone value actually consists of two parts: 1) a field tz_minuteswest indicating how many minutes local time (not adjusted for DST) lags behind UTC, and 2) a field tz_dsttime indicating the type of Daylight Savings Time (DST) convention that is in effect in the locality at the present time. This second field is not used under Linux and is always zero. See also *settimeofday*(2).Kärnans tidszonsvärde består egentligen av två delar: 1) ett fält tz_minuteswest som anger hur många minuter lokal tid (ej justerad för sommartid) ligger efter UTC, och 2) ett fält tz_dsttime som anger vilken typ av sommartidskonvention som gäller på den aktuella platsen för närvarande. Det andra fältet används inte under Linux och är alltid noll. Se även *settimeofday*(2).
inconsistent-capitalization · 16 träffar
Source starts with uppercase, translation with lowercase
The _partition_ is a device name followed by a partition number. For example, _/dev/sda1_ is the first partition on the first hard disk in the system. See also Linux kernel documentation (the _Documentation/admin-guide/devices.txt_ file)._partition_ är ett enhetsnamn följt av ett partitionsnummer. Exempelvis är _/dev/sda1_ den första partitionen på den första hårddisken i systemet. Se även dokumentationen för Linux-kärnan (filen _Documentation/admin-guide/devices.txt_).
Source starts with uppercase, translation with lowercase
The _directory_ is simply the root of the directory tree that we want to generate a compressed filesystem out of._katalog_ är helt enkelt roten till det katalogträd som vi vill generera ett komprimerat filsystem från.
Source starts with uppercase, translation with lowercase
However, *mkswap* refuses to erase the first block on a device with a disk label (SUN, BSD, ...).*mkswap* vägrar dock att radera det första blocket på en enhet med en disketikett (SUN, BSD, ...).
Source starts with uppercase, translation with lowercase
The _value_ can be between quotation marks (e.g., name="This is partition name"). The fields *start=* and *size=* support '{plus}' and '-' in the same way as *Unnamed-fields format*._värde_ kan stå mellan citattecken (t.ex. name="Detta är partitionens namn"). Fälten *start=* och *size=* stöder '{plus}' och '-' på samma sätt som *Unnamed-fields format*.Source starts with uppercase, translation with lowercase
The _name_ is a utility name. The name is optional and when none is specified then the file is used for all unspecified utilities._namn_ är namnet på ett verktyg. Namnet är valfritt och om inget namn anges används filen för alla ospecificerade verktyg.
Source starts with uppercase, translation with lowercase
The _term_ is a terminal identifier (the *TERM* environment variable). The terminal identifier is optional and when none is specified then the file is used for all unspecified terminals._term_ är en terminalidentifierare (miljövariabeln *TERM*). Terminalidentifieraren är valfri och om ingen anges används filen för alla ospecificerade terminaler.
Source starts with uppercase, translation with lowercase
The _type_ is a file type. Supported file types are:_typ_ är en filtyp. Filtyper som stöds är:
Source starts with uppercase, translation with lowercase
The _name_ is a logical name for the color sequence (for example: *error*). The names are specific to the utilities. For more details always see the *COLORS* section in the man page for the utility._namn_ är ett logiskt namn på färgsekvensen (t.ex. *error*). Namnen är specifika för verktygen. Se alltid avsnittet *FÄRGER* på verktygets manualsida för mer information.
Source starts with uppercase, translation with lowercase
The _color-sequence_ is a color name, ASCII color sequences, or escape sequences._färgsekvens_ är ett färgnamn, ASCII-färgsekvenser eller escape-sekvenser.
Source starts with uppercase, translation with lowercase
The `param` is for representing a value directly. The currently supported data types are integer, float, string and boolean.`param` används för att representera ett värde direkt. De datatyper som för närvarande stöds är integer, float, string och boolean.
Source starts with uppercase, translation with lowercase
The _month_ may be specified as a number (1-12), as a month name or as an abbreviated month name according to the current locales._månad_ kan anges som ett nummer (1-12), som ett månadsnamn eller som ett förkortat månadsnamn i enlighet med de aktuella lokala språkversionerna.
Source starts with uppercase, translation with lowercase
(Re)calculating drift factor on every shutdown delivers suboptimal results. For example, if ephemeral conditions cause the machine to be abnormally hot the drift factor calculation would be out of range.att (om)beräkna driftfaktorn vid varje avstängning ger suboptimala resultat. Om t.ex. tillfälliga förhållanden gör att maskinen blir onormalt varm skulle beräkningen av driftfaktorn hamna utanför intervallet.
Source starts with uppercase, translation with lowercase
The _/etc/mtab_ is no longer maintained in userspace, and starting from version 2.39, the mount operation can be a complex chain of operations with dependencies between the syscalls. The *--fake* option forces libmount to skip all mount source preparation, mount option analysis, and the actual mounting process._/etc/mtab_ underhålls inte längre i userspace, och från och med version 2.39 kan monteringen vara en komplex kedja av operationer med beroenden mellan syscalls. Flaggan *--fake* tvingar libmount att hoppa över all förberedelse av monteringskällan, analys av monteringsflaggor och den faktiska monteringsprocessen.
Source starts with uppercase, translation with lowercase
The _list_ is a comma-separated list of the filesystem names. The automatic filesystem detection is triggered by the "auto" filesystem type or when the filesystem type is not specified._lista_ är en kommaseparerad lista över filsystemens namn. Den automatiska filsystemdetekteringen utlöses av filsystemtypen "auto" eller när filsystemtypen inte har angetts.
Source starts with uppercase, translation with lowercase
The _list_ follows how mount evaluates type patterns (see *-t* for more details). Only specified filesystem types are allowed, or all specified types are forbidden if the list is prefixed by "no"._lista_ följer hur mount utvärderar typmönster (se *-t* för mer information). Endast angivna filsystemtyper är tillåtna, eller så är alla angivna typer förbjudna om listan inleds med "no".
Source starts with uppercase, translation with lowercase
The "xino" feature composes a unique object identifier from the real object st_ino and an underlying fsid index. The "xino" feature uses the high inode number bits for fsid, because the underlying filesystems rarely use the high inode number bits. In case the underlying inode number does overflow into the high xino bits, overlay filesystem will fall back to the non xino behavior for that inode."xino"-funktionen består av en unik objektidentifierare från det verkliga objektet st_ino och ett underliggande fsid-index. "xino"-funktionen använder de höga inodnummerbitarna för fsid, eftersom de underliggande filsystemen sällan använder de höga inodnummerbitarna. Om det underliggande inodnumret övergår till de höga xino-bitarna kommer overlay-filsystemet att återgå till icke-xino-beteendet för den inoden.
inconsistent-punctuation · 1 träffar
Extra ending punctuation (source has none)
*last* searches back through the _/var/log/wtmp_ file (or the file given with the *-f* option) and displays a list of all users who logged in (and out) since that file was created. One or more _usernames_ and/or _ttys_ can be given, in which case *last* will show only the entries matching those arguments. (Names of _ttys_ can be abbreviated, thus *last 0* is the same as *last tty0*.)*last* söker tillbaka i filen _/var/log/wtmp_ (eller den fil som anges med flaggan *-f*) och visar en lista över alla användare som loggat in (och ut) sedan filen skapades. Ett eller flera _användarnamn_ och/eller _ttys_ kan anges, och i så fall visar *last* endast de poster som matchar dessa argument. Namnen på _ttys_ kan förkortas, så *last 0* är detsamma som *last tty0*.
keyboard-shortcut-missing · 1 träffar
Keyboard accelerator missing in translation
_port_port
length-ratio · 1 träffar
Translation is 3.2x longer than source
BUGSKÄNDA PROBLEM
newline-mismatch · 1 träffar
Newline count mismatch: source has 0, translation has 1
Report man page translation bugs to: <%1>Rapportera översättningsfel för manualsidor till: <%1> Har du synpunkter på översättning, kontakta <tp-sv@listor.tp-sv.se>
nordic-accelerator · 4 träffar
Nordic character 'å' used as keyboard accelerator
*cal* [options] [[[_day_] _month_] _year_]*cal* [flaggor] [[[_dag_] _månad_] _år_]
Nordic character 'å' used as keyboard accelerator
Specifies the _year_ to be displayed; note the year must be fully specified: *cal 89* will not display a calendar for 1989.Anger vilket _år_ som ska visas; observera att året måste vara fullständigt angivet: *cal 89* kommer inte att visa en kalender för 1989.
Nordic character 'å' used as keyboard accelerator
Denote the _month_ (1 - 12) and _year_.Ange _månad_ (1 - 12) och _år_.
Nordic character 'ö' used as keyboard accelerator
Users other than the superuser may alter the priority only of processes they own. Furthermore, an unprivileged user can only _increase_ the "nice value" (that is: lower the urgency), and such changes are irreversible unless (since Linux 2.6.12) the user has a suitable "nice" resource limit (see *getrlimit*(2)).Andra användare än superanvändaren får endast ändra prioriteten för processer de äger. Dessutom kan en användare utan privilegier endast _öka_ ”nice-värdet” (alltså sänka angelägenhetsgraden), och sådana ändringar kan inte återställas om inte användaren har en lämplig ”nice”-resursgräns (sedan Linux 2.6.12; se *getrlimit*(2)).
numeric-mismatch · 3 träffar
Numbers {'0.5'} from source missing in translation
List timerfd files expired within 0.5 seconds: Lista timerfd-filer som förföll inom 0,5 sekunder:
Numbers {'8.3'} from source missing in translation
Defines the behavior for creation and display of filenames which fit into 8.3 characters. If a long name for a file exists, it will always be the preferred one for display. There are four __mode__s:Definierar beteendet för skapande och visning av filnamn som ryms inom 8,3 tecken. Om det finns ett långt namn för en fil kommer det alltid att föredras för visning. Det finns fyra __läge__s:
Numbers {'0.1'} from source missing in translation
If the third parameter or *--divisor* is specified, it is used as a speed-up multiplier. For example, a speed-up of 2 makes *scriptreplay* go twice as fast, and a speed-down of 0.1 makes it go ten times slower than the original session.Om den tredje parametern eller *--divisor* anges används den som en multiplikator för hastighetshöjning. Om t.ex. hastigheten ökas med 2 går *scriptreplay* dubbelt så snabbt och om hastigheten minskas med 0,1 går den tio gånger långsammare än den ursprungliga sessionen.
punctuation-mismatch · 31 träffar
Source contains ';' but translation does not
Start with an in-memory zeroed partition table. This option does not zero the partition table on the disk; rather, it simply starts the program without reading the existing partition table. This option allows you to create a new partition table from scratch or from an *sfdisk*(8)-compatible script.Starta med en nollställd partitionstabell i minnet. Den här flaggan nollställer inte partitionstabellen på disken, utan startar programmet utan att läsa den befintliga partitionstabellen. Med den här flaggan kan du skapa en ny partitionstabell från början eller från ett *sfdisk*(8)-kompatibelt skript.
Source contains ';' but translation does not
Wipe filesystem, RAID and partition-table signatures from the device, in order to avoid possible collisions. The argument _when_ can be *auto*, *never* or *always*. When this option is not given, the default is *auto*, in which case signatures are wiped only when in interactive mode; except the old partition-table signatures which are always wiped before create a new partition-table if the argument _when_ is not *never*. The *auto* mode also does not wipe the first sector (boot sector), it is necessary to use the *always* mode to wipe this area. In all cases detected signatures are reported by warning messages before a new partition table is created. See also the *wipefs*(8) command.Raderar filsystem-, RAID- och partitionstabellsignaturer från enheten för att undvika eventuella kollisioner. Argumentet _när_ kan vara *auto*, *never* eller *always*. Om denna flagga inte anges är standardvärdet *auto*, vilket innebär att signaturer endast rensas i interaktivt läge, med undantag för gamla partitionstabellsignaturer som alltid rensas innan en ny partitionstabell skapas om argumentet _när_ inte är *never*. I *auto*-läget rensas inte heller den första sektorn (startsektorn), utan det är nödvändigt att använda *always*-läget för att rensa detta område. I samtliga fall rapporteras upptäckta signaturer i form av varningsmeddelanden innan en ny partitionstabell skapas. Se även kommandot *wipefs*(8).
Source contains ':' but translation does not
The _name_ is a logical name for the color sequence (for example: *error*). The names are specific to the utilities. For more details always see the *COLORS* section in the man page for the utility._namn_ är ett logiskt namn på färgsekvensen (t.ex. *error*). Namnen är specifika för verktygen. Se alltid avsnittet *FÄRGER* på verktygets manualsida för mer information.
Source contains ';' but translation does not
`=~` and `!~` is for regular expression matching; if a string at the right side matches (or not matches for `!~` a regular expression at the left side), the result is true. The right side operand must be a string literal.`=~` och `!~` används för matchning med reguljära uttryck. Resultatet är sant om en sträng på höger sida matchar (eller inte matchar, för `!~`) ett reguljärt uttryck på vänster sida. Operanden på höger sida måste vara en strängliteral.
Source contains ':' but translation does not
The *-Q* option with a PID (for example: *-Q PID==1*) and the *-p* option (for example: *-p 1*) can be used to achieve the same result, but using the *-p* option is much more efficient because it works at a much earlier stage of processing than the *-Q* option.Flaggan *-Q* med en PID (exempelvis *-Q PID==1*) och flaggan *-p* (exempelvis *-p 1*) kan ge samma resultat, men *-p* är mycket effektivare eftersom den verkar i ett mycket tidigare skede av bearbetningen än *-Q*.
Source contains ';' but translation does not
Search for block devices with tokens named _NAME_ that have the value _value_, and display any devices which are found. Common values for _NAME_ include *TYPE*, *LABEL*, and *UUID*. If there are no devices specified on the command line, all block devices will be searched; otherwise only the specified devices are searched.Sök efter blockenheter med tokens med namnet _NAME_ som har värdet _värde_ och visa alla enheter som hittas. Vanliga värden för _NAME_ är *TYPE*, *LABEL* och *UUID*. Om det inte finns några enheter angivna på kommandoraden söks alla blockenheter, annars söks endast de angivna enheterna.
Source contains ';' but translation does not
_gregorian_ - display Gregorian calendars exclusively. This special placeholder sets the reform date below the smallest year that *cal* can use; meaning all calendar output uses the Gregorian calendar system. This is called the proleptic Gregorian calendar, because dates prior to the calendar system's creation use extrapolated values._gregorian_ - visar enbart gregorianska kalendrar. Denna speciella platshållare sätter reformdatumet under det minsta år som *cal* kan använda, vilket innebär att all kalenderutmatning använder det gregorianska kalendersystemet. Detta kallas den proleptiska gregorianska kalendern, eftersom datum före kalendersystemets skapande använder extrapolerade värden.
Source contains ';' but translation does not
_julian_ - display Julian calendars exclusively. This special placeholder sets the reform date above the largest year that *cal* can use; meaning all calendar output uses the Julian calendar system._julian_ - visar endast julianska kalendrar. Denna speciella platshållare sätter reformdatumet över det största år som *cal* kan använda, vilket innebär att all kalenderutmatning använder det julianska kalendersystemet.
Source contains ';' but translation does not
The kernel guarantees that the inode number associated with a process's file descriptor is exempt from reuse during the current boot cycle; therefore, a process can be uniquely identified by its PID and the inode number, conveniently so with the format '_PID:inode_'. As an example, this enables race-free signalling of processes with *kill*(1), which accepts the aforementioned _PID_ format.Kärnan garanterar att inodnumret som hör till en processfilbeskrivare inte återanvänds under den aktuella startcykeln. Därför kan en process identifieras entydigt med sin PID och sitt inodnummer, lämpligen i formatet ”_PID:inode_”. Detta möjliggör exempelvis signalering av processer utan kapplöpningstillstånd med *kill*(1), som accepterar det nämnda _PID_-formatet.
Source contains ';' but translation does not
Sets the link:https://tools.ietf.org/html/rfc5424[RFC 5424] MSGID field. Note that the space character is not permitted inside of _msgid_. This option is only used if *--rfc5424* is specified as well; otherwise, it is silently ignored.Anger fältet link:https://tools.ietf.org/html/rfc5424[RFC 5424] MSGID. Observera att mellanslagstecken inte är tillåtet inuti _msgid_. Den här flaggan används bara om *--rfc5424* också anges, annars ignoreras det.
Source contains ':' but translation does not
Define a custom counter. Custom counters are printed after the standard output. The _name_ is the custom name of the counter, the optional _parameter_ is the name of the column to be used for the counter, and the optional _function_ specifies the aggregation function. Supported functions are: *count*, *min*, *max*, *sum*. The default function is *count*. If _parameter_ is not specified, then the counter counts the number of lines.Definiera en anpassad räknare. Anpassade räknare skrivs ut efter den vanliga utmatningen. _namn_ är räknarens anpassade namn, valfria _parameter_ är namnet på kolumnen som ska användas för räknaren och valfria _funktion_ anger aggregeringsfunktionen. Funktioner som stöds är *count*, *min*, *max*, *sum*. Standardfunktionen är *count*. Om _parameter_ inte anges räknas antalet rader.
Source contains ':' but translation does not
The *lsblk* command needs to be able to look up each block device by major:minor numbers, which is done by using _/sys/dev/block_. This sysfs block directory appeared in kernel 2.6.27 (October 2008). In case of problems with a new enough kernel, check that *CONFIG_SYSFS* was enabled at the time of the kernel build.Kommandot *lsblk* måste kunna slå upp varje blockenhet med major- och minor-nummer, vilket görs med hjälp av _/sys/dev/block_. Denna sysfs-blockkatalog dök upp i kärnan 2.6.27 (oktober 2008). Om du får problem med en tillräckligt ny kärna, kontrollera att *CONFIG_SYSFS* var aktiverat när kärnan byggdes.
Source contains ':' but translation does not
Interpret _mask_ as numerical list of processors instead of a bitmask. Numbers are separated by commas and may include ranges. For example: *0,5,8-11*.Tolka _mask_ som en numerisk lista över processorer i stället för en bitmask. Siffrorna separeras med kommatecken och kan innehålla intervall. Till exempel *0,5,8-11*.
Source contains ':' but translation does not
The command for managing persistent reservations. Supported commands are: *register*, *reserve*, *release*, *preempt*, *preempt-abort*, *clear*, *read-keys*, and *read-reservation*.Kommandot för att hantera beständiga reservationer. Kommandon som stöds är *register*, *reserve*, *release*, *preempt*, *preempt-abort*, *clear*, *read-keys* och *read-reservation*.
Source contains ';' but translation does not
Unfortunately, some Linux distributions are changing it back to the old tree structure in their packages. So the problem of system administrators reaching into the 'right' subdirectory persists. This causes the system timezone to be configured to include leap seconds while the zoneinfo database is still configured to exclude them. Then when an application such as a World Clock needs the South_Pole timezone file; or an email MTA, or *hwclock* needs the UTC timezone file; they fetch it from the root of _/usr/share/zoneinfo_ , because that is what they are supposed to do. Those files exclude leap seconds, but the System Clock now includes them, causing an incorrect time conversion.Tyvärr ändrar vissa Linux-distributioner tillbaka till den gamla trädstrukturen i sina paket. Så problemet med att systemadministratörer hamnar i "rätt" underkatalog kvarstår. Detta gör att systemets tidszon konfigureras för att inkludera skottsekunder medan zoneinfo-databasen fortfarande är konfigurerad för att utesluta dem. När sedan en applikation som ett världsklocka behöver tidszonsfilen för South_Pole, eller en e-post-MTA, eller *hwclock* behöver UTC-tidszonsfilen, hämtar de den från roten till _/usr/share/zoneinfo_, eftersom det är vad de ska göra. Dessa filer utesluter skottsekunder, men systemklockan inkluderar dem nu, vilket orsakar en felaktig tidsomvandling.
Source contains ';' but translation does not
The data start is moved _offset_ bytes into the specified file or device. The _offset_ may be followed by the multiplicative suffixes; see above.Datastarten flyttas _offset_ byte in i den angivna filen eller enheten. _offset_ kan följas av de multiplikativa suffixen, se ovan.
Source contains ';' but translation does not
The data end is set to no more than _size_ bytes after the data start. The _size_ may be followed by the multiplicative suffixes; see above.Dataslutet sätts till högst _storlek_ bytes efter datastarten. _storlek_ kan följas av de multiplikativa suffixen, se ovan.
Source contains ':' but translation does not
The *lsmem* command always lists a new memory range when the current memory block differs from the previous block by some output column. This default behavior can be overridden with the *--split* option (for example: *lsmem --split=ZONES*). The special word *none* may be used with *--split* to ignore all differences between memory blocks and to create contiguous ranges that are as large as possible. The opposite semantics has *--all*, which lists all individual memory blocks.Kommandot *lsmem* listar alltid ett nytt minnesintervall när det aktuella minnesblocket skiljer sig från det föregående i någon utdatakolumn. Standardbeteendet kan åsidosättas med flaggan *--split* (exempelvis *lsmem --split=ZONES*). Specialordet *none* kan användas med *--split* för att ignorera alla skillnader mellan minnesblock och skapa så stora sammanhängande intervall som möjligt. Motsatt innebörd har *--all*, som listar alla enskilda minnesblock.
Source contains ';' but translation does not
This feature is not supported by the Linux kernel; it is implemented in userspace by an additional *mount*(2) remounting system call. This solution is not atomic.Den här funktionen stöds inte av Linux-kärnan, utan implementeras i användarutrymmet med ett extra systemanrop för återmontering, *mount*(2). Den här lösningen är inte atomär.
Source contains ';' but translation does not
See also the **--onlyonce** option. The difference between *--onlyonce* and *--exclusive* is that "onlyonce" ensures the same source is not mounted on the same mount point; this means mounting twice on /A is not allowed, but mounting on /A and /B is allowed. The "exclusive" mount ensures the filesystem itself is not reused, regardless of the mount point.Se även flaggan **--onlyonce**. Skillnaden mellan *--onlyonce* och *--exclusive* är att ”onlyonce” säkerställer att samma källa inte monteras på samma monteringspunkt. Två monteringar på /A tillåts alltså inte, medan montering på både /A och /B tillåts. En ”exclusive”-montering säkerställer att själva filsystemet inte återanvänds, oavsett monteringspunkt.
Source contains ';' but translation does not
The *-t* and *-O* options are cumulative in effect; that is, the commandFlaggorna *-t* och *-O* har kumulativ effekt, vilket innebär att kommandot
Source contains ':' but translation does not
Users other than the superuser may alter the priority only of processes they own. Furthermore, an unprivileged user can only _increase_ the "nice value" (that is: lower the urgency), and such changes are irreversible unless (since Linux 2.6.12) the user has a suitable "nice" resource limit (see *getrlimit*(2)).Andra användare än superanvändaren får endast ändra prioriteten för processer de äger. Dessutom kan en användare utan privilegier endast _öka_ ”nice-värdet” (alltså sänka angelägenhetsgraden), och sådana ändringar kan inte återställas om inte användaren har en lämplig ”nice”-resursgräns (sedan Linux 2.6.12; se *getrlimit*(2)).
Source contains ';' but translation does not
The suspend setup may be interrupted by active hardware; for example wireless USB input devices that continue to send events for some fraction of a second after the return key is pressed. *rtcwake* tries to avoid this problem and it waits to the terminal to settle down before entering a system sleep.Suspend-inställningen kan avbrytas av aktiv maskinvara, t.ex. trådlösa USB-ingångar som fortsätter att skicka händelser under en bråkdel av en sekund efter att returtangenten har tryckts ned. *rtcwake* försöker undvika detta problem och väntar på att terminalen ska lugna ner sig innan den går in i systemvila.
Source contains ';' but translation does not
The *list of supported algorithms could be inaccurate* as it depends on the current kernel configuration. A basic overview can be obtained by using the command "cat /sys/block/zram0/comp_algorithm"; however, please note that this list might also be incomplete. This is due to the fact that ZRAM utilizes the Crypto API, and if certain algorithms were built as modules, it becomes impossible to enumerate all of them.*Listan över algoritmer som stöds kan vara felaktig* eftersom den beror på den aktuella kärnkonfigurationen. En grundläggande översikt kan erhållas genom att använda kommandot "cat /sys/block/zram0/comp_algorithm", men observera att även denna lista kan vara ofullständig. Detta beror på att ZRAM använder Crypto API, och om vissa algoritmer byggdes som moduler blir det omöjligt att räkna upp dem alla.
Source contains ':' but translation does not
Insert the IPv4 address of the specified network interface (for example: \4\{eth0}). If the _interface_ argument is not specified, then select the first fully configured (UP, non-LOCALBACK, RUNNING) interface. If no configured interface is found, fall back to the IP address of the machine's hostname.Ange IPv4-adressen för det angivna nätverksgränssnittet (t.ex. \4\{eth0}). Om argumentet _interface_ inte anges, väljs det första fullt konfigurerade (UP, non-LOCALBACK, RUNNING) gränssnittet. Om inget konfigurerat gränssnitt hittas, faller du tillbaka till IP-adressen för maskinens värdnamn.Source contains ';' but translation does not
Depending on how the program was configured, all diagnostics are written to the console device or reported via the *syslog*(3) facility. Error messages are produced if the _port_ argument does not specify a terminal device; if there is no utmp entry for the current process (System V only); and so on.Beroende på hur programmet har konfigurerats skrivs all diagnostik till konsolenheten eller rapporteras via *syslog*(3)-funktionen. Felmeddelanden genereras om argumentet _port_ inte anger en terminalenhet, om det inte finns någon utmp-post för den aktuella processen (endast System V), och så vidare.
Source contains ':' but translation does not
*script* is primarily designed for interactive terminal sessions. When stdin is not a terminal (for example: *echo foo | script*), then the session can hang, because the interactive shell within the script session misses EOF and *script* has no clue when to close the session. See the *NOTES* section for more information.*script* är främst utformat för interaktiva terminalsessioner. När stdin inte är en terminal (t.ex. *echo foo | script*) kan sessionen hänga sig, eftersom det interaktiva skalet i skriptsessionen missar EOF och *script* inte har någon aning om när sessionen ska stängas. Se avsnittet *ANMÄRKNINGAR* för mer information.
Source contains ':' but translation does not
A set of bits specified as a hexadecimal mask value (for example: *0xeec2*).En uppsättning bitar angiven som ett hexadecimalt maskvärde (exempelvis *0xeec2*).
Source contains ':' but translation does not
Optionally, if an argument starts with a comma, it will be parsed as a single hexadecimal mask split in 32-bit groups (for example: *,00014000,00000000,00020000* -> *17,78,80*).Om ett argument börjar med ett kommatecken tolkas det som en enda hexadecimal mask uppdelad i 32-bitarsgrupper (exempelvis *,00014000,00000000,00020000* -> *17,78,80*).
Source contains ':' but translation does not
The group will be combined with a binary AND operation. That is: all bits that are set to 1 in the group AND in the combined groups so far will be preserved as 1. All other bits will be reset to 0.Gruppen kombineras med en binär AND-operation. Det innebär att alla bitar som är satta till 1 i gruppen OCH i de hittills kombinerade grupperna bevaras som 1. Alla andra bitar återställs till 0.
Source contains ':' but translation does not
The group will be combined with a binary XOR operation. That is: all bits that are set to 1 in the group AND to 0 in the combined groups so far (or the other way around) will be set to 1. Bits that are set both to 1 or both to 0 will be reset to 0.Gruppen kombineras med en binär XOR-operation. Det innebär att alla bitar som är satta till 1 i gruppen OCH till 0 i de hittills kombinerade grupperna (eller tvärtom) sätts till 1. Bitar som är 1 i båda eller 0 i båda återställs till 0.
repeated-words · 19 träffar
Repeated word: 'om'
Filesystem errors corrected, system should be rebooted if filesystem was mountedFel i filsystemet korrigerade, systemet bör startas om om filsystemet var monterat
Repeated word: '_'
*raw* _/dev/raw/raw<N>_ _<major>_ _<minor>_*raw* _/dev/raw/raw<N>_ _<major>_ _<minor>_
Repeated word: '_'
*raw* _/dev/raw/raw<N>_ _/dev/<blockdev>_*raw* _/dev/raw/raw<N>_ _/dev/<blockdev>_
Repeated word: 'för'
helps *lsblk*(1) to not read LABELs for all block device from udevd or libblkid, but read it only for device sda1.hjälper *lsblk*(1) att endast läsa LABEL från udevd eller libblkid för enheten sda1, i stället för för alla blockenheter.
Repeated word: 'ENOSYS'
# fail syscall "fallocate" with ENOSYS
enosys -s fallocate ...
# misslyckas med syscall "fallocate" med ENOSYS enosys -s fallocate ...
Repeated word: '0'
$ ps ax -o comm,psr,pid | grep ksoftirqd/0
ksoftirqd/0 0 14
$ sudo taskset -p 1 14
pid 14's current affinity mask: 1
taskset: failed to set pid 14's affinity: Invalid argument
$ echo $?
1 +$ ps ax -o comm,psr,pid | grep ksoftirqd/0 ksoftirqd/0 0 14 $ sudo taskset -p 1 14 pid 14:s aktuella affinitetsmask: 1 taskset: misslyckades med att ställa in pid 14:s affinitet: Ogiltigt argument $ echo $? 1 +
Repeated word: '_'
*uclampset* _[-m uclamp_min]_ _[-M uclamp_max]_ _command_ [_arguments_]*uclampset* _[-m uclamp_min]_ _[-M uclamp_max]_ _kommando_ [_arguments_]
Repeated word: '_'
*uclampset -p* _PID_ _[-m uclamp_min]_ _[-M uclamp_max]_*uclampset -p* _PID_ _[-m uclamp_min]_ _[-M uclamp_max]_
Repeated word: '_'
*uclampset -s* _[-m uclamp_min]_ _[-M uclamp_max]_*uclampset -s* _[-m uclamp_min]_ _[-M uclamp_max]_
Repeated word: 'som'
For each hole the offset, end and size in bytes are printed in verbose mode, followed by a summary that gives the total size and percentage of the file that each hole type represents by default. If no offset is specified with *--offset*, the whole file is scanned.För varje hål skrivs startposition, slutposition och storlek i byte ut i utförligt läge, följt av en sammanfattning som som standard anger total storlek och andel av filen för varje håltyp. Om ingen position anges med *--offset* söks hela filen igenom.
Repeated word: 'den'
Suppose you start with no adjtime file. You issue a *hwclock --set* command to set the Hardware Clock to the true current time. *hwclock* creates the adjtime file and records in it the current time as the last time the clock was calibrated. Five days later, the clock has gained 10 seconds, so you issue a *hwclock --set --update-drift* command to set it back 10 seconds. *hwclock* updates the adjtime file to show the current time as the last time the clock was calibrated, and records 2 seconds per day as the systematic drift rate. 24 hours go by, and then you issue a *hwclock --adjust* command. *hwclock* consults the adjtime file and sees that the clock gains 2 seconds per day when left alone and that it has been left alone for exactly one day. So it subtracts 2 seconds from the Hardware Clock. It then records the current time as the last time the clock was adjusted. Another 24 hours go by and you issue another *hwclock --adjust*. *hwclock* does the same thing: subtracts 2 seconds and updates the adjtime file with the current time as the last time the clock was adjusted.Anta att du börjar med att inte ha någon adjtime-fil. Du ger kommandot *hwclock --set* för att ställa in maskinvaruklockan till den verkliga aktuella tiden. *hwclock* skapar adjtime-filen och registrerar i den den aktuella tiden när klockan senast kalibrerades. Fem dagar senare har klockan gått fram 10 sekunder, så du ger kommandot *hwclock --set --update-drift* för att ställa tillbaka den 10 sekunder. *hwclock* uppdaterar adjtime-filen så att den visar den aktuella tiden som den senaste gången klockan kalibrerades, och registrerar 2 sekunder per dag som den systematiska drifthastigheten. 24 timmar går, och sedan ger du kommandot *hwclock --adjust*. *hwclock* konsulterar adjtime-filen och ser att klockan vinner 2 sekunder per dag när den lämnas i fred och att den har lämnats i fred i exakt en dag. Så den subtraherar 2 sekunder från maskinvaruklockan. Sedan registreras den aktuella tiden som den senaste gången klockan justerades. Ytterligare 24 timmar går och du utfärdar en ny *hwclock --adjust*. *hwclock* gör samma sak: subtraherar 2 sekunder och uppdaterar adjtime-filen med den aktuella tiden då klockan senast justerades.
Repeated word: 'q'
*q Q**q Q*
Repeated word: '_'
_/dev/loop[0..N]__/dev/loop[0..N]_ _/dev/loop[0..N]_
Repeated word: 'foo'
*mount --bind foo foo**mount --bind foo foo*
Repeated word: 'foo'
*mount -o bind,ro foo foo**mount -o bind,ro foo foo*
Repeated word: 'overlay'
mount -t overlay overlay \
-olowerdir=/lower,upperdir=/upper,workdir=/work /merged
mount -t overlay overlay \ -olowerdir=/lower,upperdir=/upper,workdir=/work /merged
Repeated word: '1000'
$ id -u; id -g
1000
1000
$ unshare --user --map-root-user \
sh -c 'whoami; cat /proc/self/uid_map /proc/self/gid_map'
root
0 1000 1
0 1000 1
$ id -u; id -g
1000
1000
$ unshare --user --map-root-user \
sh -c 'whoami; cat /proc/self/uid_map /proc/self/gid_map'
root
0 1000 1
0 1000 1
Repeated word: '1'
$ id -u
1000
$ cat /etc/subuid
1000:100000:65536
$ unshare --user --map-auto --map-root-user
# id -u
0
# cat /proc/self/uid_map
0 1000 1
1 100000 65535
# touch file; chown 1:1 file
# ls -ln --time-style=+ file
-rw-r--r-- 1 1 1 0 file
# exit
$ ls -ln --time-style=+ file
-rw-r--r-- 1 100000 100000 0 file
$ id -u
1000
$ cat /etc/subuid
1000:100000:65536
$ unshare --user --map-auto --map-root-user
# id -u
0
# cat /proc/self/uid_map
0 1000 1
1 100000 65535
# touch file; chown 1:1 file
# ls -ln --time-style=+ file
-rw-r--r-- 1 1 1 0 file
# exit
$ ls -ln --time-style=+ file
-rw-r--r-- 1 100000 100000 0 file
Repeated word: '_'
_/dev/zram[0..N]__/dev/zram[0..N]_ _/dev/zram[0..N]_
source-equals-translation · 898 träffar
Translation is identical to source (possibly untranslated)
_/etc/terminal-colors.d/disable__/etc/terminal-colors.d/disable_
Translation is identical to source (possibly untranslated)
*LIBSMARTCOLS_DEBUG*=all*LIBSMARTCOLS_DEBUG*=all
Translation is identical to source (possibly untranslated)
*LIBSMARTCOLS_DEBUG_PADDING*=on*LIBSMARTCOLS_DEBUG_PADDING*=on
Translation is identical to source (possibly untranslated)
*-h*, *--help**-h*, *--help*
Translation is identical to source (possibly untranslated)
*-V*, *--version**-V*, *--version*
Translation is identical to source (possibly untranslated)
*blockdev* *-h*|*-V**blockdev* *-h*|*-V*
Translation is identical to source (possibly untranslated)
*--getdiscardzeroes**--getdiscardzeroes*
Translation is identical to source (possibly untranslated)
*--setbsz* _bytes_*--setbsz* _bytes_
Translation is identical to source (possibly untranslated)
*-r*, *--read-only**-r*, *--read-only*
Translation is identical to source (possibly untranslated)
*-z*, *--zero**-z*, *--zero*
Translation is identical to source (possibly untranslated)
*CFDISK_DEBUG*=all*CFDISK_DEBUG*=all
Translation is identical to source (possibly untranslated)
*LIBFDISK_DEBUG*=all*LIBFDISK_DEBUG*=all
Translation is identical to source (possibly untranslated)
*LIBBLKID_DEBUG*=all*LIBBLKID_DEBUG*=all
Translation is identical to source (possibly untranslated)
*-f*, *--from* _N_*-f*, *--from* _N_
Translation is identical to source (possibly untranslated)
*-r*, *--repair* _N_*-r*, *--repair* _N_
Translation is identical to source (possibly untranslated)
*-n*, *--no-verify**-n*, *--no-verify*
Translation is identical to source (possibly untranslated)
*-B*, *--protect-boot**-B*, *--protect-boot*
Translation is identical to source (possibly untranslated)
*-l*, *--list**-l*, *--list*
Translation is identical to source (possibly untranslated)
*-x*, *--list-details**-x*, *--list-details*
Translation is identical to source (possibly untranslated)
*-n*, *--noauto-pt**-n*, *--noauto-pt*
Translation is identical to source (possibly untranslated)
*-s*, *--getsz**-s*, *--getsz*
Translation is identical to source (possibly untranslated)
*BSD/Sun-type**BSD/Sun-type*
Translation is identical to source (possibly untranslated)
*IRIX/SGI-type**IRIX/SGI-type*
Translation is identical to source (possibly untranslated)
*FDISK_DEBUG*=all*FDISK_DEBUG*=all
Translation is identical to source (possibly untranslated)
*/dev/sda1: status 0, rss 92828, real 4.002804, user 2.677592, sys 0.86186**/dev/sda1: status 0, rss 92828, real 4.002804, user 2.677592, sys 0.86186*
Translation is identical to source (possibly untranslated)
*-t* _fslist_*-t* _fslist_
Translation is identical to source (possibly untranslated)
*FSCK_FORCE_ALL_PARALLEL**FSCK_FORCE_ALL_PARALLEL*
Translation is identical to source (possibly untranslated)
*FSCK_MAX_INST**FSCK_MAX_INST*
Translation is identical to source (possibly untranslated)
*PATH**PATH*
Translation is identical to source (possibly untranslated)
*FSTAB_FILE**FSTAB_FILE*
Translation is identical to source (possibly untranslated)
*LIBBLKID_DEBUG=all**LIBBLKID_DEBUG=all*
Translation is identical to source (possibly untranslated)
*LIBMOUNT_DEBUG=all**LIBMOUNT_DEBUG=all*
Translation is identical to source (possibly untranslated)
*-v*, *--verbose**-v*, *--verbose*
Translation is identical to source (possibly untranslated)
*-b*, *--blocksize* _blocksize_*-b*, *--blocksize* _blocksize_
Translation is identical to source (possibly untranslated)
*-r*, *--repair**-r*, *--repair*
Translation is identical to source (possibly untranslated)
*-a*, *--auto**-a*, *--auto*
Translation is identical to source (possibly untranslated)
*-s*, *--super**-s*, *--super*
Translation is identical to source (possibly untranslated)
*-m*, *--uncleared**-m*, *--uncleared*
Translation is identical to source (possibly untranslated)
*-f*, *--force**-f*, *--force*
Translation is identical to source (possibly untranslated)
*-x*, *--sectors**-x*, *--sectors*
Translation is identical to source (possibly untranslated)
*-V*, *--verbose**-V*, *--verbose*
Translation is identical to source (possibly untranslated)
*-b* _blocksize_*-b* _blocksize_
Translation is identical to source (possibly untranslated)
*-e* _edition_*-e* _edition_
Translation is identical to source (possibly untranslated)
*-c*, *--check**-c*, *--check*
Translation is identical to source (possibly untranslated)
*-l*, *--badblocks* _filename_*-l*, *--badblocks* _filename_
Translation is identical to source (possibly untranslated)
*-F*, *--file**-F*, *--file*
Translation is identical to source (possibly untranslated)
*-q*, *--quiet**-q*, *--quiet*
Translation is identical to source (possibly untranslated)
*-U*, *--uuid* _UUID_*-U*, *--uuid* _UUID_
Translation is identical to source (possibly untranslated)
*-e*, *--endianness* _ENDIANNESS_*-e*, *--endianness* _ENDIANNESS_
Translation is identical to source (possibly untranslated)
*-o*, *--offset* _offset_*-o*, *--offset* _offset_
Translation is identical to source (possibly untranslated)
partx --show - /dev/sda3partx --show - /dev/sda3
Translation is identical to source (possibly untranslated)
*-a*, *--add**-a*, *--add*
Translation is identical to source (possibly untranslated)
*-b*, *--bytes**-b*, *--bytes*
Translation is identical to source (possibly untranslated)
*-d*, *--delete**-d*, *--delete*
Translation is identical to source (possibly untranslated)
*-g*, *--noheadings**-g*, *--noheadings*
Translation is identical to source (possibly untranslated)
*-P*, *--pairs**-P*, *--pairs*
Translation is identical to source (possibly untranslated)
*-r*, *--raw**-r*, *--raw*
Translation is identical to source (possibly untranslated)
*-s*, *--show**-s*, *--show*
Translation is identical to source (possibly untranslated)
*-u*, *--update**-u*, *--update*
Translation is identical to source (possibly untranslated)
partx --show /dev/sdb3partx --show /dev/sdb3
Translation is identical to source (possibly untranslated)
partx --show --nr 3 /dev/sdbpartx --show --nr 3 /dev/sdb
Translation is identical to source (possibly untranslated)
partx --show /dev/sdb3 /dev/sdbpartx --show /dev/sdb3 /dev/sdb
Translation is identical to source (possibly untranslated)
partx --show - /dev/sdb3partx --show - /dev/sdb3
Translation is identical to source (possibly untranslated)
partx -o START -g --nr 5 /dev/sdbpartx -o START -g --nr 5 /dev/sdb
Translation is identical to source (possibly untranslated)
partx --add --nr 3:5 /dev/sddpartx --add --nr 3:5 /dev/sdd
Translation is identical to source (possibly untranslated)
partx -d --nr -1: /dev/sddpartx -d --nr -1: /dev/sdd
Translation is identical to source (possibly untranslated)
*raw* *-qa**raw* *-qa*
Translation is identical to source (possibly untranslated)
*-q*, *--query**-q*, *--query*
Translation is identical to source (possibly untranslated)
*-a*, *--all**-a*, *--all*
Translation is identical to source (possibly untranslated)
*resizepart* _device partition length_*resizepart* _device partition length_
Translation is identical to source (possibly untranslated)
*Bits 3-47**Bits 3-47*
Translation is identical to source (possibly untranslated)
*Bits 48-63**Bits 48-63*
Translation is identical to source (possibly untranslated)
*-T*, *--list-types**-T*, *--list-types*
Translation is identical to source (possibly untranslated)
*-a*, *--append**-a*, *--append*
Translation is identical to source (possibly untranslated)
*-b*, *--backup**-b*, *--backup*
Translation is identical to source (possibly untranslated)
*--Linux**--Linux*
Translation is identical to source (possibly untranslated)
*-n*, *--no-act**-n*, *--no-act*
Translation is identical to source (possibly untranslated)
*--no-tell-kernel**--no-tell-kernel*
Translation is identical to source (possibly untranslated)
*echo '+100M,' | sfdisk --move-data /dev/sdc -N 1**echo '+100M,' | sfdisk --move-data /dev/sdc -N 1*
Translation is identical to source (possibly untranslated)
*echo '2048,' | sfdisk /dev/sdc --append**echo '2048,' | sfdisk /dev/sdc --append*
Translation is identical to source (possibly untranslated)
*sfdisk /dev/sdc --reorder**sfdisk /dev/sdc --reorder*
Translation is identical to source (possibly untranslated)
*--move-use-fsync**--move-use-fsync*
Translation is identical to source (possibly untranslated)
*-u*, *--unit S**-u*, *--unit S*
Translation is identical to source (possibly untranslated)
*-v*, *--version**-v*, *--version*
Translation is identical to source (possibly untranslated)
_start size type bootable__start size type bootable_
Translation is identical to source (possibly untranslated)
*L - alias 'linux'**L - alias 'linux'*
Translation is identical to source (possibly untranslated)
*S - alias 'swap'**S - alias 'swap'*
Translation is identical to source (possibly untranslated)
*Ex - alias 'extended'**Ex - alias 'extended'*
Translation is identical to source (possibly untranslated)
*H - alias 'home'**H - alias 'home'*
Translation is identical to source (possibly untranslated)
*R - alias 'raid'**R - alias 'raid'*
Translation is identical to source (possibly untranslated)
**type=**__code__**type=**__code__
Translation is identical to source (possibly untranslated)
*echo 'label: gpt' | sfdisk /dev/sdb**echo 'label: gpt' | sfdisk /dev/sdb*
Translation is identical to source (possibly untranslated)
*sfdisk --dump /dev/sda > sda.dump**sfdisk --dump /dev/sda > sda.dump*
Translation is identical to source (possibly untranslated)
*sfdisk /dev/sda < sda.dump**sfdisk /dev/sda < sda.dump*
Translation is identical to source (possibly untranslated)
*sfdisk --backup-pt-sectors /dev/sda**sfdisk --backup-pt-sectors /dev/sda*
Translation is identical to source (possibly untranslated)
*sfdisk --backup --delete /dev/sda**sfdisk --backup --delete /dev/sda*
Translation is identical to source (possibly untranslated)
*SFDISK_DEBUG*=all*SFDISK_DEBUG*=all
Translation is identical to source (possibly untranslated)
*sfdisk --list --label-nested=mbr /dev/sda**sfdisk --list --label-nested=mbr /dev/sda*
Translation is identical to source (possibly untranslated)
*echo -e ',10M,L\n,10M,L\n,+,\n' | sfdisk /dev/sdc**echo -e ',10M,L\n,10M,L\n,+,\n' | sfdisk /dev/sdc*
Translation is identical to source (possibly untranslated)
*sfdisk --part-type /dev/sdc 3 swap**sfdisk --part-type /dev/sdc 3 swap*
Translation is identical to source (possibly untranslated)
*sfdisk --delete /dev/sdc 2**sfdisk --delete /dev/sdc 2*
Translation is identical to source (possibly untranslated)
*echo "\+,+" | sfdisk -N 3 --move-data /dev/sdc**echo "\+,+" | sfdisk -N 3 --move-data /dev/sdc*
Translation is identical to source (possibly untranslated)
*TERMINAL_COLORS_DEBUG*=all*TERMINAL_COLORS_DEBUG*=all
Translation is identical to source (possibly untranslated)
*NO_COLOR**NO_COLOR*
Translation is identical to source (possibly untranslated)
_$XDG_CONFIG_HOME/terminal-colors.d__$XDG_CONFIG_HOME/terminal-colors.d_
Translation is identical to source (possibly untranslated)
_$HOME/.config/terminal-colors.d__$HOME/.config/terminal-colors.d_
Translation is identical to source (possibly untranslated)
_/etc/terminal-colors.d__/etc/terminal-colors.d_
Translation is identical to source (possibly untranslated)
*touch /etc/terminal-colors.d/disable**touch /etc/terminal-colors.d/disable*
Translation is identical to source (possibly untranslated)
*touch /etc/terminal-colors.d/dmesg.enable**touch /etc/terminal-colors.d/dmesg.enable*
Translation is identical to source (possibly untranslated)
*cc* _file.c_ *-lblkid**cc* _file.c_ *-lblkid*
Translation is identical to source (possibly untranslated)
SBMAGIC - super block magic stringSBMAGIC - super block magic string
Translation is identical to source (possibly untranslated)
float: integer.integer
float: integer.integer
Translation is identical to source (possibly untranslated)
Theodore Y. Ts'oTheodore Y. Ts'o
Translation is identical to source (possibly untranslated)
*-f*, *--full-name* _full-name_*-f*, *--full-name* _full-name_
Translation is identical to source (possibly untranslated)
*-o*, *--office* _office_*-o*, *--office* _office_
Translation is identical to source (possibly untranslated)
*-p*, *--office-phone* _office-phone_*-p*, *--office-phone* _office-phone_
Translation is identical to source (possibly untranslated)
*-h*, *--home-phone* _home-phone_*-h*, *--home-phone* _home-phone_
Translation is identical to source (possibly untranslated)
*-u*, *--help**-u*, *--help*
Translation is identical to source (possibly untranslated)
*-l*, *--list-shells**-l*, *--list-shells*
Translation is identical to source (possibly untranslated)
*-a*, *--hostlast**-a*, *--hostlast*
Translation is identical to source (possibly untranslated)
*-d*, *--dns**-d*, *--dns*
Translation is identical to source (possibly untranslated)
*-F*, *--fulltimes**-F*, *--fulltimes*
Translation is identical to source (possibly untranslated)
*-p*, *--present* _time_*-p*, *--present* _time_
Translation is identical to source (possibly untranslated)
*-R*, *--nohostname**-R*, *--nohostname*
Translation is identical to source (possibly untranslated)
*-s*, *--since* _time_*-s*, *--since* _time_
Translation is identical to source (possibly untranslated)
*-t*, *--until* _time_*-t*, *--until* _time_
Translation is identical to source (possibly untranslated)
*-T*, *--tab-separated**-T*, *--tab-separated*
Translation is identical to source (possibly untranslated)
*--time-format* _format_*--time-format* _format_
Translation is identical to source (possibly untranslated)
*-w*, *--fullnames**-w*, *--fullnames*
Translation is identical to source (possibly untranslated)
*-x*, *--system**-x*, *--system*
Translation is identical to source (possibly untranslated)
_/var/log/wtmp_, _/var/log/btmp__/var/log/wtmp_, _/var/log/btmp_
Translation is identical to source (possibly untranslated)
_/var/run/utmp_, _/var/log/wtmp_, _/var/log/lastlog_, _/var/spool/mail/*_, _/etc/motd_, _/etc/passwd_, _/etc/nologin_, _/etc/pam.d/login_, _/etc/pam.d/remote_, _/etc/hushlogins_, _$HOME/.hushlogin__/var/run/utmp_, _/var/log/wtmp_, _/var/log/lastlog_, _/var/spool/mail/*_, _/etc/motd_, _/etc/passwd_, _/etc/nologin_, _/etc/pam.d/login_, _/etc/pam.d/remote_, _/etc/hushlogins_, _$HOME/.hushlogin_
Translation is identical to source (possibly untranslated)
*-a*, *--acc-expiration**-a*, *--acc-expiration*
Translation is identical to source (possibly untranslated)
*-c*, *--colon-separate**-c*, *--colon-separate*
Translation is identical to source (possibly untranslated)
*-e*, *--export**-e*, *--export*
Translation is identical to source (possibly untranslated)
*-f*, *--failed**-f*, *--failed*
Translation is identical to source (possibly untranslated)
*-G*, *--supp-groups**-G*, *--supp-groups*
Translation is identical to source (possibly untranslated)
*-L*, *--last**-L*, *--last*
Translation is identical to source (possibly untranslated)
*-l*, *--logins* _logins_*-l*, *--logins* _logins_
Translation is identical to source (possibly untranslated)
*-n*, *--newline**-n*, *--newline*
Translation is identical to source (possibly untranslated)
*-H*, *--list-columns**-H*, *--list-columns*
Translation is identical to source (possibly untranslated)
*-p*, *--pwd**-p*, *--pwd*
Translation is identical to source (possibly untranslated)
*-J*, *--json**-J*, *--json*
Translation is identical to source (possibly untranslated)
*-s*, *--system-accs**-s*, *--system-accs*
Translation is identical to source (possibly untranslated)
*-u*, *--user-accs**-u*, *--user-accs*
Translation is identical to source (possibly untranslated)
*-y*, *--shell**-y*, *--shell*
Translation is identical to source (possibly untranslated)
*-Z*, *--context**-Z*, *--context*
Translation is identical to source (possibly untranslated)
*-z*, *--print0**-z*, *--print0*
Translation is identical to source (possibly untranslated)
_/etc/group_, _/etc/passwd__/etc/group_, _/etc/passwd_
Translation is identical to source (possibly untranslated)
*-i* *--interactive**-i* *--interactive*
Translation is identical to source (possibly untranslated)
*-i*, *--interactive**-i*, *--interactive*
Translation is identical to source (possibly untranslated)
*-l*, *--login**-l*, *--login*
Translation is identical to source (possibly untranslated)
*-r*, *--restricted**-r*, *--restricted*
Translation is identical to source (possibly untranslated)
*-f*, *--fast**-f*, *--fast*
Translation is identical to source (possibly untranslated)
*-*, *-l*, *--login**-*, *-l*, *--login*
Translation is identical to source (possibly untranslated)
*-m*, *-p*, *--preserve-environment**-m*, *-p*, *--preserve-environment*
Translation is identical to source (possibly untranslated)
*-P*, *--pty**-P*, *--pty*
Translation is identical to source (possibly untranslated)
*-T*, *--no-pty**-T*, *--no-pty*
Translation is identical to source (possibly untranslated)
_/etc/pam.d/runuser__/etc/pam.d/runuser_
Translation is identical to source (possibly untranslated)
_/etc/pam.d/runuser-l__/etc/pam.d/runuser-l_
Translation is identical to source (possibly untranslated)
_/etc/default/runuser__/etc/default/runuser_
Translation is identical to source (possibly untranslated)
_/etc/login.defs__/etc/login.defs_
Translation is identical to source (possibly untranslated)
_/etc/pam.d/su-l__/etc/pam.d/su-l_
Translation is identical to source (possibly untranslated)
_/etc/default/su__/etc/default/su_
Translation is identical to source (possibly untranslated)
session required pam_lastlog.so nowtmpsession required pam_lastlog.so nowtmp
Translation is identical to source (possibly untranslated)
*-e*, *--force**-e*, *--force*
Translation is identical to source (possibly untranslated)
*-p*, *--login-shell**-p*, *--login-shell*
Translation is identical to source (possibly untranslated)
*-t*, *--timeout* _seconds_*-t*, *--timeout* _seconds_
Translation is identical to source (possibly untranslated)
*-f*, *--follow**-f*, *--follow*
Translation is identical to source (possibly untranslated)
*-r*, *--reverse**-r*, *--reverse*
Translation is identical to source (possibly untranslated)
*EDITOR**EDITOR*
Translation is identical to source (possibly untranslated)
*-l*, *--threads**-l*, *--threads*
Translation is identical to source (possibly untranslated)
*-n*, *--noheadings**-n*, *--noheadings*
Translation is identical to source (possibly untranslated)
*--debug-filter**--debug-filter*
Translation is identical to source (possibly untranslated)
*--dump-counters**--dump-counters*
Translation is identical to source (possibly untranslated)
Bpf program ID.Bpf program ID.
Translation is identical to source (possibly untranslated)
tfds=_EVENTPOLL.TFDS_tfds=_EVENTPOLL.TFDS_
Translation is identical to source (possibly untranslated)
id=_EVENTFD.ID_id=_EVENTFD.ID_
Translation is identical to source (possibly untranslated)
inodes=_INOTIFY.INODES_inodes=_INOTIFY.INODES_
Translation is identical to source (possibly untranslated)
tty-index=_PTMX.TTY-INDEX_tty-index=_PTMX.TTY-INDEX_
Translation is identical to source (possibly untranslated)
mask=_SIGNALFD.MASK_mask=_SIGNALFD.MASK_
Translation is identical to source (possibly untranslated)
# lsfd --pid 1,2
# lsfd --pid 1,2
Translation is identical to source (possibly untranslated)
# lsfd --pid '1 2'
# lsfd --pid '1 2'
Translation is identical to source (possibly untranslated)
# lsfd -Q 'ASSOC eq "exe"'
# lsfd -Q 'ASSOC eq "exe"'
Translation is identical to source (possibly untranslated)
# lsfd -Q 'DELETED'
# lsfd -Q 'DELETED'
Translation is identical to source (possibly untranslated)
*-c*, *--cache-file* _cachefile_*-c*, *--cache-file* _cachefile_
Translation is identical to source (possibly untranslated)
*-d*, *--no-encoding**-d*, *--no-encoding*
Translation is identical to source (possibly untranslated)
*-D*, *--no-part-details**-D*, *--no-part-details*
Translation is identical to source (possibly untranslated)
*-g*, *--garbage-collect**-g*, *--garbage-collect*
Translation is identical to source (possibly untranslated)
*-H*, *--hint* _setting_*-H*, *--hint* _setting_
Translation is identical to source (possibly untranslated)
*-i*, *--info**-i*, *--info*
Translation is identical to source (possibly untranslated)
*-k*, *--list-filesystems**-k*, *--list-filesystems*
Translation is identical to source (possibly untranslated)
*-l*, *--list-one**-l*, *--list-one*
Translation is identical to source (possibly untranslated)
*blkid --probe --match-types vfat,ext3,ext4 /dev/sda1**blkid --probe --match-types vfat,ext3,ext4 /dev/sda1*
Translation is identical to source (possibly untranslated)
*blkid --probe --match-types nominix /dev/sda1**blkid --probe --match-types nominix /dev/sda1*
Translation is identical to source (possibly untranslated)
*-o*, *--output* _format_*-o*, *--output* _format_
Translation is identical to source (possibly untranslated)
*-O*, *--offset* _offset_*-O*, *--offset* _offset_
Translation is identical to source (possibly untranslated)
*-p*, *--probe**-p*, *--probe*
Translation is identical to source (possibly untranslated)
*-t*, *--match-token* _NAME=value_*-t*, *--match-token* _NAME=value_
Translation is identical to source (possibly untranslated)
*blkid --probe --usages filesystem,other /dev/sda1**blkid --probe --usages filesystem,other /dev/sda1*
Translation is identical to source (possibly untranslated)
*blkid --probe --usages noraid /dev/sda1**blkid --probe --usages noraid /dev/sda1*
Translation is identical to source (possibly untranslated)
*-U*, *--uuid* _uuid_*-U*, *--uuid* _uuid_
Translation is identical to source (possibly untranslated)
*-3*, *--three**-3*, *--three*
Translation is identical to source (possibly untranslated)
*-S, --span**-S, --span*
Translation is identical to source (possibly untranslated)
*-s*, *--sunday**-s*, *--sunday*
Translation is identical to source (possibly untranslated)
*-m*, *--monday**-m*, *--monday*
Translation is identical to source (possibly untranslated)
*-v*, *--vertical**-v*, *--vertical*
Translation is identical to source (possibly untranslated)
*-j*, *--julian**-j*, *--julian*
Translation is identical to source (possibly untranslated)
*--reform* _val_*--reform* _val_
Translation is identical to source (possibly untranslated)
*-y*, *--year**-y*, *--year*
Translation is identical to source (possibly untranslated)
*-Y, --twelve**-Y, --twelve*
Translation is identical to source (possibly untranslated)
copyfilerange original-file reflink ::
copyfilerange original-file reflink ::
Translation is identical to source (possibly untranslated)
copyfilerange original-file first-block ::4096
copyfilerange original-file first-block ::4096
Translation is identical to source (possibly untranslated)
copyfilerange original-file sparse-file 0:1M:1
copyfilerange original-file sparse-file 0:1M:1
Translation is identical to source (possibly untranslated)
copyfilerange original-file split-first-mb ::1M
copyfilerange original-file split-first-mb ::1M
Translation is identical to source (possibly untranslated)
copyfilerange original-file split-remainder 1M::
copyfilerange original-file split-remainder 1M::
Translation is identical to source (possibly untranslated)
copyfilerange split-first-mb join ::
copyfilerange split-first-mb join ::
Translation is identical to source (possibly untranslated)
copyfilerange split-remainder join 1M::
copyfilerange split-remainder join 1M::
Translation is identical to source (possibly untranslated)
*-s*, *--syscall**-s*, *--syscall*
Translation is identical to source (possibly untranslated)
*-i*, *--ioctl**-i*, *--ioctl*
Translation is identical to source (possibly untranslated)
*-m*, *--list-ioctl**-m*, *--list-ioctl*
Translation is identical to source (possibly untranslated)
*-d*, *--fd* _file-descriptor_*-d*, *--fd* _file-descriptor_
Translation is identical to source (possibly untranslated)
*-a*, *--advice* _advice_*-a*, *--advice* _advice_
Translation is identical to source (possibly untranslated)
*-c*, *--total**-c*, *--total*
Translation is identical to source (possibly untranslated)
*-C*, *--cachestat**-C*, *--cachestat*
Translation is identical to source (possibly untranslated)
*-R*, *--recursive**-R*, *--recursive*
Translation is identical to source (possibly untranslated)
**UUID=**_uuid_**UUID=**_uuid_
Translation is identical to source (possibly untranslated)
**PARTUUID=**_uuid_**PARTUUID=**_uuid_
Translation is identical to source (possibly untranslated)
*lsblk --fs**lsblk --fs*
Translation is identical to source (possibly untranslated)
*partx --show* _disk_*partx --show* _disk_
Translation is identical to source (possibly untranslated)
*-A*, *--all**-A*, *--all*
Translation is identical to source (possibly untranslated)
*-a*, *--ascii**-a*, *--ascii*
Translation is identical to source (possibly untranslated)
*-C*, *--nocanonicalize**-C*, *--nocanonicalize*
Translation is identical to source (possibly untranslated)
*-c*, *--canonicalize**-c*, *--canonicalize*
Translation is identical to source (possibly untranslated)
*-d*, *--direction* _word_*-d*, *--direction* _word_
Translation is identical to source (possibly untranslated)
*-e*, *--evaluate**-e*, *--evaluate*
Translation is identical to source (possibly untranslated)
*-f*, *--first-only**-f*, *--first-only*
Translation is identical to source (possibly untranslated)
*-I*, *--dfi**-I*, *--dfi*
Translation is identical to source (possibly untranslated)
*-i*, *--invert**-i*, *--invert*
Translation is identical to source (possibly untranslated)
*-m*, *--mtab**-m*, *--mtab*
Translation is identical to source (possibly untranslated)
*-N*, *--task* _tid_*-N*, *--task* _tid_
Translation is identical to source (possibly untranslated)
*ACTION**ACTION*
Translation is identical to source (possibly untranslated)
*OLD-TARGET**OLD-TARGET*
Translation is identical to source (possibly untranslated)
*OLD-OPTIONS**OLD-OPTIONS*
Translation is identical to source (possibly untranslated)
*-Q*, *--filter* _expr_*-Q*, *--filter* _expr_
Translation is identical to source (possibly untranslated)
*-R*, *--submounts**-R*, *--submounts*
Translation is identical to source (possibly untranslated)
*-S*, *--source* _spec_*-S*, *--source* _spec_
Translation is identical to source (possibly untranslated)
*-s*, *--fstab**-s*, *--fstab*
Translation is identical to source (possibly untranslated)
*-U*, *--uniq**-U*, *--uniq*
Translation is identical to source (possibly untranslated)
*-u*, *--notruncate**-u*, *--notruncate*
Translation is identical to source (possibly untranslated)
*-v*, *--nofsroot**-v*, *--nofsroot*
Translation is identical to source (possibly untranslated)
*-x*, *--verify**-x*, *--verify*
Translation is identical to source (possibly untranslated)
*LIBMOUNT_DEBUG*=all*LIBMOUNT_DEBUG*=all
Translation is identical to source (possibly untranslated)
*findmnt --fstab -t nfs**findmnt --fstab -t nfs*
Translation is identical to source (possibly untranslated)
*findmnt --fstab /mnt/foo**findmnt --fstab /mnt/foo*
Translation is identical to source (possibly untranslated)
*findmnt --fstab --target /mnt/foo**findmnt --fstab --target /mnt/foo*
Translation is identical to source (possibly untranslated)
*findmnt --fstab --evaluate**findmnt --fstab --evaluate*
Translation is identical to source (possibly untranslated)
*findmnt --poll --mountpoint /mnt/foo**findmnt --poll --mountpoint /mnt/foo*
Translation is identical to source (possibly untranslated)
*findmnt --poll=umount --first-only --mountpoint /mnt/foo**findmnt --poll=umount --first-only --mountpoint /mnt/foo*
Translation is identical to source (possibly untranslated)
*findmnt --poll=remount -t ext3 -O ro**findmnt --poll=remount -t ext3 -O ro*
Translation is identical to source (possibly untranslated)
*-p*, *--print-pid**-p*, *--print-pid*
Translation is identical to source (possibly untranslated)
*-a*, *--alternative**-a*, *--alternative*
Translation is identical to source (possibly untranslated)
*-l*, *--longoptions* _longopts_*-l*, *--longoptions* _longopts_
Translation is identical to source (possibly untranslated)
*-n*, *--name* _progname_*-n*, *--name* _progname_
Translation is identical to source (possibly untranslated)
*-o*, *--options* _shortopts_*-o*, *--options* _shortopts_
Translation is identical to source (possibly untranslated)
*-Q*, *--quiet-output**-Q*, *--quiet-output*
Translation is identical to source (possibly untranslated)
*-T*, *--test**-T*, *--test*
Translation is identical to source (possibly untranslated)
*-u*, *--unquoted**-u*, *--unquoted*
Translation is identical to source (possibly untranslated)
*-U*, *--unknown**-U*, *--unknown*
Translation is identical to source (possibly untranslated)
*POSIXLY_CORRECT**POSIXLY_CORRECT*
Translation is identical to source (possibly untranslated)
*GETOPT_COMPATIBLE**GETOPT_COMPATIBLE*
Translation is identical to source (possibly untranslated)
*-c*, *--content**-c*, *--content*
Translation is identical to source (possibly untranslated)
*-d*, *--respect-dir**-d*, *--respect-dir*
Translation is identical to source (possibly untranslated)
*-f*, *--respect-name**-f*, *--respect-name*
Translation is identical to source (possibly untranslated)
*-F*, *--prioritize-trees**-F*, *--prioritize-trees*
Translation is identical to source (possibly untranslated)
*-i*, *--include* _regex_*-i*, *--include* _regex_
Translation is identical to source (possibly untranslated)
*-l*, *--list-duplicates**-l*, *--list-duplicates*
Translation is identical to source (possibly untranslated)
*-m*, *--maximize**-m*, *--maximize*
Translation is identical to source (possibly untranslated)
*-M*, *--minimize**-M*, *--minimize*
Translation is identical to source (possibly untranslated)
*-n*, *--dry-run**-n*, *--dry-run*
Translation is identical to source (possibly untranslated)
*-o*, *--ignore-owner**-o*, *--ignore-owner*
Translation is identical to source (possibly untranslated)
*-O*, *--keep-oldest**-O*, *--keep-oldest*
Translation is identical to source (possibly untranslated)
*-p*, *--ignore-mode**-p*, *--ignore-mode*
Translation is identical to source (possibly untranslated)
*--skip-reflinks**--skip-reflinks*
Translation is identical to source (possibly untranslated)
*-t*, *--ignore-time**-t*, *--ignore-time*
Translation is identical to source (possibly untranslated)
*-x*, *--exclude* _regex_*-x*, *--exclude* _regex_
Translation is identical to source (possibly untranslated)
*--exclude-subtree* _regex_*--exclude-subtree* _regex_
Translation is identical to source (possibly untranslated)
*-X*, *--respect-xattrs**-X*, *--respect-xattrs*
Translation is identical to source (possibly untranslated)
*ULFILEEQ_DEBUG*=all*ULFILEEQ_DEBUG*=all
Translation is identical to source (possibly untranslated)
*kill* *-d* _pid_*kill* *-d* _pid_
Translation is identical to source (possibly untranslated)
*-s*, *--signal* _signal_*-s*, *--signal* _signal_
Translation is identical to source (possibly untranslated)
*-L*, *--table**-L*, *--table*
Translation is identical to source (possibly untranslated)
*-p*, *--pid**-p*, *--pid*
Translation is identical to source (possibly untranslated)
*-r*, *--require-handler**-r*, *--require-handler*
Translation is identical to source (possibly untranslated)
*--timeout* _milliseconds signal_*--timeout* _milliseconds signal_
Translation is identical to source (possibly untranslated)
kill --verbose --timeout 1000 TERM --timeout 1000 KILL \
--signal QUIT 12345
kill --verbose --timeout 1000 TERM --timeout 1000 KILL \
--signal QUIT 12345
Translation is identical to source (possibly untranslated)
*-d*, *--show-process-state* _pid_*-d*, *--show-process-state* _pid_
Translation is identical to source (possibly untranslated)
*-a*, *--active**-a*, *--active*
Translation is identical to source (possibly untranslated)
*-C*, *--clear**-C*, *--clear*
Translation is identical to source (possibly untranslated)
*-s*, *--service**-s*, *--service*
Translation is identical to source (possibly untranslated)
*-S*, *--set**-S*, *--set*
Translation is identical to source (possibly untranslated)
*/var/lib/lastlog/lastlog2.db**/var/lib/lastlog/lastlog2.db*
Translation is identical to source (possibly untranslated)
*-d*, *--udp**-d*, *--udp*
Translation is identical to source (possibly untranslated)
*-e*, *--skip-empty**-e*, *--skip-empty*
Translation is identical to source (possibly untranslated)
*--msgid* _msgid_*--msgid* _msgid_
Translation is identical to source (possibly untranslated)
*-n*, *--server* _server_*-n*, *--server* _server_
Translation is identical to source (possibly untranslated)
*-P*, *--port* _port_*-P*, *--port* _port_
Translation is identical to source (possibly untranslated)
*-p*, *--priority* _priority_*-p*, *--priority* _priority_
Translation is identical to source (possibly untranslated)
*-s*, *--stderr**-s*, *--stderr*
Translation is identical to source (possibly untranslated)
*-T*, *--tcp**-T*, *--tcp*
Translation is identical to source (possibly untranslated)
logger -p local0.notice -t HOSTIDM -f /dev/idmclogger -p local0.notice -t HOSTIDM -f /dev/idmc
Translation is identical to source (possibly untranslated)
*-d*, *--alphanum**-d*, *--alphanum*
Translation is identical to source (possibly untranslated)
*-f*, *--ignore-case**-f*, *--ignore-case*
Translation is identical to source (possibly untranslated)
*-t*, *--terminate* _character_*-t*, *--terminate* _character_
Translation is identical to source (possibly untranslated)
*WORDLIST**WORDLIST*
Translation is identical to source (possibly untranslated)
_/usr/share/dict/web2__/usr/share/dict/web2_
Translation is identical to source (possibly untranslated)
sort -d /etc/passwd -o /tmp/look.dict
look -t: root:foobar /tmp/look.dict
sort -d /etc/passwd -o /tmp/look.dict look -t: root:foobar /tmp/look.dict
Translation is identical to source (possibly untranslated)
*-A*, *--noempty**-A*, *--noempty*
Translation is identical to source (possibly untranslated)
*-D*, *--discard**-D*, *--discard*
Translation is identical to source (possibly untranslated)
*-d*, *--nodeps**-d*, *--nodeps*
Translation is identical to source (possibly untranslated)
*-E*, *--dedup* _column_*-E*, *--dedup* _column_
Translation is identical to source (possibly untranslated)
*-i*, *--ascii**-i*, *--ascii*
Translation is identical to source (possibly untranslated)
*-M*, *--merge**-M*, *--merge*
Translation is identical to source (possibly untranslated)
*-m*, *--perms**-m*, *--perms*
Translation is identical to source (possibly untranslated)
*-N*, *--nvme**-N*, *--nvme*
Translation is identical to source (possibly untranslated)
*-v*, *--virtio**-v*, *--virtio*
Translation is identical to source (possibly untranslated)
*-O*, *--output-all**-O*, *--output-all*
Translation is identical to source (possibly untranslated)
*-p*, *--paths**-p*, *--paths*
Translation is identical to source (possibly untranslated)
*-S*, *--scsi**-S*, *--scsi*
Translation is identical to source (possibly untranslated)
*-s*, *--inverse**-s*, *--inverse*
Translation is identical to source (possibly untranslated)
*-t*, *--topology**-t*, *--topology*
Translation is identical to source (possibly untranslated)
*-x*, *--sort* _column_*-x*, *--sort* _column_
Translation is identical to source (possibly untranslated)
*-z*, *--zoned**-z*, *--zoned*
Translation is identical to source (possibly untranslated)
*LSBLK_DEBUG*=all*LSBLK_DEBUG*=all
Translation is identical to source (possibly untranslated)
*LSBLK_COLUMNS*=*LSBLK_COLUMNS*=
Translation is identical to source (possibly untranslated)
*--no-discover-dynamic**--no-discover-dynamic*
Translation is identical to source (possibly untranslated)
*--no-discover-rtc**--no-discover-rtc*
Translation is identical to source (possibly untranslated)
*-c*, *--cpu-clock* _pid_*-c*, *--cpu-clock* _pid_
Translation is identical to source (possibly untranslated)
*-i*, *--noinaccessible**-i*, *--noinaccessible*
Translation is identical to source (possibly untranslated)
*-p*, *--pid* _pid_*-p*, *--pid* _pid_
Translation is identical to source (possibly untranslated)
*xauth add :0 . `mcookie`**xauth add :0 . `mcookie`*
Translation is identical to source (possibly untranslated)
*-l*, *--long**-l*, *--long*
Translation is identical to source (possibly untranslated)
*-m*, *--modes**-m*, *--modes*
Translation is identical to source (possibly untranslated)
*-n*, *--nosymlinks**-n*, *--nosymlinks*
Translation is identical to source (possibly untranslated)
*-o*, *--owners**-o*, *--owners*
Translation is identical to source (possibly untranslated)
*-x*, *--mountpoints**-x*, *--mountpoints*
Translation is identical to source (possibly untranslated)
*-g*, *--get**-g*, *--get*
Translation is identical to source (possibly untranslated)
*-i*, *--stdin**-i*, *--stdin*
Translation is identical to source (possibly untranslated)
*-o*, *--stdout**-o*, *--stdout*
Translation is identical to source (possibly untranslated)
*-e*, *--stderr**-e*, *--stderr*
Translation is identical to source (possibly untranslated)
*pipesz* -s1M -cf _/run/my-service.fifo_*pipesz* -s1M -cf _/run/my-service.fifo_
Translation is identical to source (possibly untranslated)
*-s*, *--symlink**-s*, *--symlink*
Translation is identical to source (possibly untranslated)
*-l*, *--last**-l*, *--last*
Translation is identical to source (possibly untranslated)
*-o*, *--no-overwrite**-o*, *--no-overwrite*
Translation is identical to source (possibly untranslated)
rename foo foo00 foo?
rename foo foo0 foo??
rename foo foo00 foo? rename foo foo0 foo??
Translation is identical to source (possibly untranslated)
rename .htm .html *.htm
rename .htm .html *.htm
Translation is identical to source (possibly untranslated)
*-d*, *--debug**-d*, *--debug*
Translation is identical to source (possibly untranslated)
*-F*, *--no-fork**-F*, *--no-fork*
Translation is identical to source (possibly untranslated)
*-k*, *--kill**-k*, *--kill*
Translation is identical to source (possibly untranslated)
*-P*, *--no-pid**-P*, *--no-pid*
Translation is identical to source (possibly untranslated)
*-r*, *--random**-r*, *--random*
Translation is identical to source (possibly untranslated)
*-S*, *--socket-activation**-S*, *--socket-activation*
Translation is identical to source (possibly untranslated)
*-t*, *--time**-t*, *--time*
Translation is identical to source (possibly untranslated)
uuidd -p /tmp/uuidd.pid -s /tmp/uuidd.socket
uuidd -d -r -n 42 -s /tmp/uuidd.socket
uuidd -d -k -s /tmp/uuidd.socket
uuidd -p /tmp/uuidd.pid -s /tmp/uuidd.socket uuidd -d -r -n 42 -s /tmp/uuidd.socket uuidd -d -k -s /tmp/uuidd.socket
Translation is identical to source (possibly untranslated)
*-C*, *--count* _num_*-C*, *--count* _num_
Translation is identical to source (possibly untranslated)
*-x*, *--hex**-x*, *--hex*
Translation is identical to source (possibly untranslated)
*-o*, *--output**-o*, *--output*
Translation is identical to source (possibly untranslated)
*-e*, *--exited**-e*, *--exited*
Translation is identical to source (possibly untranslated)
*-c*, *--count* _count_*-c*, *--count* _count_
Translation is identical to source (possibly untranslated)
*whereis -bm ls tr -m gcc**whereis -bm ls tr -m gcc*
Translation is identical to source (possibly untranslated)
*whereis -m ls -M /usr/share/man/man1 -f cal**whereis -m ls -M /usr/share/man/man1 -f cal*
Translation is identical to source (possibly untranslated)
whereis -g 'find*'
whereis -g 'find*'
Translation is identical to source (possibly untranslated)
*WHEREIS_DEBUG*=all*WHEREIS_DEBUG*=all
Translation is identical to source (possibly untranslated)
*cd /usr/bin*
*whereis -u -ms -M /usr/man/man1 -S /usr/src -f ***cd /usr/bin* *whereis -u -ms -M /usr/man/man1 -S /usr/src -f **
Translation is identical to source (possibly untranslated)
*-i*, *--noheadings**-i*, *--noheadings*
Translation is identical to source (possibly untranslated)
*-p*, *--parsable**-p*, *--parsable*
Translation is identical to source (possibly untranslated)
*wipefs /dev/sda***wipefs /dev/sda**
Translation is identical to source (possibly untranslated)
*wipefs --all --backup /dev/sdb**wipefs --all --backup /dev/sdb*
Translation is identical to source (possibly untranslated)
*-o*, *--other**-o*, *--other*
Translation is identical to source (possibly untranslated)
*-f*, *--fifo**-f*, *--fifo*
Translation is identical to source (possibly untranslated)
*-b*, *--batch**-b*, *--batch*
Translation is identical to source (possibly untranslated)
*-i*, *--idle**-i*, *--idle*
Translation is identical to source (possibly untranslated)
*-d*, *--deadline**-d*, *--deadline*
Translation is identical to source (possibly untranslated)
*-e*, *--ext**-e*, *--ext*
Translation is identical to source (possibly untranslated)
*-T*, *--sched-runtime* _nanoseconds_*-T*, *--sched-runtime* _nanoseconds_
Translation is identical to source (possibly untranslated)
*-P*, *--sched-period* _nanoseconds_*-P*, *--sched-period* _nanoseconds_
Translation is identical to source (possibly untranslated)
*-D*, *--sched-deadline* _nanoseconds_*-D*, *--sched-deadline* _nanoseconds_
Translation is identical to source (possibly untranslated)
*-R*, *--reset-on-fork**-R*, *--reset-on-fork*
Translation is identical to source (possibly untranslated)
*-a*, *--all-tasks**-a*, *--all-tasks*
Translation is identical to source (possibly untranslated)
*-m*, *--max**-m*, *--max*
Translation is identical to source (possibly untranslated)
*chrt --pid* _PID_*chrt --pid* _PID_
Translation is identical to source (possibly untranslated)
*chrt --pid -r 30 1234**chrt --pid -r 30 1234*
Translation is identical to source (possibly untranslated)
*chrt --pid -o 0* _PID_*chrt --pid -o 0* _PID_
Translation is identical to source (possibly untranslated)
*chrt --pid -o -T 1000000* _PID_*chrt --pid -o -T 1000000* _PID_
Translation is identical to source (possibly untranslated)
*-s*, *--source* _PID_*-s*, *--source* _PID_
Translation is identical to source (possibly untranslated)
*-d*, *--dest* _PID_*-d*, *--dest* _PID_
Translation is identical to source (possibly untranslated)
*-t*, *--dest-type* _TYPE_*-t*, *--dest-type* _TYPE_
Translation is identical to source (possibly untranslated)
*Idle**Idle*
Translation is identical to source (possibly untranslated)
*Best-effort**Best-effort*
Translation is identical to source (possibly untranslated)
*Realtime**Realtime*
Translation is identical to source (possibly untranslated)
*-p*, *--pid* _PID_...*-p*, *--pid* _PID_...
Translation is identical to source (possibly untranslated)
*-P*, *--pgid* _PGID_...*-P*, *--pgid* _PGID_...
Translation is identical to source (possibly untranslated)
*-t*, *--ignore**-t*, *--ignore*
Translation is identical to source (possibly untranslated)
*-u*, *--uid* _UID_...*-u*, *--uid* _UID_...
Translation is identical to source (possibly untranslated)
# *ionice* -c 3 -p 89# *ionice* -c 3 -p 89
Translation is identical to source (possibly untranslated)
# *ionice* -c 2 -n 0 bash# *ionice* -c 2 -n 0 bash
Translation is identical to source (possibly untranslated)
# *ionice* -p 89 91# *ionice* -p 89 91
Translation is identical to source (possibly untranslated)
*FFFFFFFF**FFFFFFFF*
Translation is identical to source (possibly untranslated)
*--cpu-list 0-2,6**--cpu-list 0-2,6*
Translation is identical to source (possibly untranslated)
*--cpu-list 0-10:2**--cpu-list 0-10:2*
Translation is identical to source (possibly untranslated)
*-c*, *--cpu-list**-c*, *--cpu-list*
Translation is identical to source (possibly untranslated)
*taskset -p* _pid_*taskset -p* _pid_
Translation is identical to source (possibly untranslated)
*taskset -p* _mask pid_*taskset -p* _mask pid_
Translation is identical to source (possibly untranslated)
*taskset -pc* _cpu-list pid_*taskset -pc* _cpu-list pid_
Translation is identical to source (possibly untranslated)
*taskset --cpu-list* _cpu-list command_*taskset --cpu-list* _cpu-list command_
Translation is identical to source (possibly untranslated)
*-s*, *--system**-s*, *--system*
Translation is identical to source (possibly untranslated)
*uclampset -p* _PID_*uclampset -p* _PID_
Translation is identical to source (possibly untranslated)
*uclampset -s* `-m 512` `-M 700`*uclampset -s* `-m 512` `-M 700`
Translation is identical to source (possibly untranslated)
*-s*, *--secure**-s*, *--secure*
Translation is identical to source (possibly untranslated)
*-z*, *--zeroout**-z*, *--zeroout*
Translation is identical to source (possibly untranslated)
*-o*, *--offset* _sector_*-o*, *--offset* _sector_
Translation is identical to source (possibly untranslated)
*-k*, *--key* _key_*-k*, *--key* _key_
Translation is identical to source (possibly untranslated)
*-K*, *--oldkey* _oldkey_*-K*, *--oldkey* _oldkey_
Translation is identical to source (possibly untranslated)
*-f*, *--flag* _flag_*-f*, *--flag* _flag_
Translation is identical to source (possibly untranslated)
*-c*, *--configure* _cpu-list_*-c*, *--configure* _cpu-list_
Translation is identical to source (possibly untranslated)
*-d*, *--disable* _cpu-list_*-d*, *--disable* _cpu-list_
Translation is identical to source (possibly untranslated)
*-e*, *--enable* _cpu-list_*-e*, *--enable* _cpu-list_
Translation is identical to source (possibly untranslated)
*-g*, *--deconfigure* _cpu-list_*-g*, *--deconfigure* _cpu-list_
Translation is identical to source (possibly untranslated)
*-r*, *--rescan**-r*, *--rescan*
Translation is identical to source (possibly untranslated)
*-b*, *--blocks**-b*, *--blocks*
Translation is identical to source (possibly untranslated)
*-c*, *--configure**-c*, *--configure*
Translation is identical to source (possibly untranslated)
*-d*, *--disable**-d*, *--disable*
Translation is identical to source (possibly untranslated)
*-e*, *--enable**-e*, *--enable*
Translation is identical to source (possibly untranslated)
*-g*, *--deconfigure**-g*, *--deconfigure*
Translation is identical to source (possibly untranslated)
*-m*, *--memmap-on-memory**-m*, *--memmap-on-memory*
Translation is identical to source (possibly untranslated)
*-z*, *--zone**-z*, *--zone*
Translation is identical to source (possibly untranslated)
*chmem --enable 1024**chmem --enable 1024*
Translation is identical to source (possibly untranslated)
*chmem -e 2g**chmem -e 2g*
Translation is identical to source (possibly untranslated)
*chmem --disable 0x00000000e4000000-0x00000000f3ffffff**chmem --disable 0x00000000e4000000-0x00000000f3ffffff*
Translation is identical to source (possibly untranslated)
*chmem -b -d 10**chmem -b -d 10*
Translation is identical to source (possibly untranslated)
*chmem -b -c 10 -m 1**chmem -b -c 10 -m 1*
Translation is identical to source (possibly untranslated)
*chmem -b -c 10**chmem -b -c 10*
Translation is identical to source (possibly untranslated)
*chmem -b -g 10**chmem -b -g 10*
Translation is identical to source (possibly untranslated)
*chmem -d 5g**chmem -d 5g*
Translation is identical to source (possibly untranslated)
*choom* *-p* _PID_*choom* *-p* _PID_
Translation is identical to source (possibly untranslated)
*ctrlaltdel* *hard*|*soft**ctrlaltdel* *hard*|*soft*
Translation is identical to source (possibly untranslated)
*dmesg* *--clear**dmesg* *--clear*
Translation is identical to source (possibly untranslated)
*dmesg* *--console-level* _level_*dmesg* *--console-level* _level_
Translation is identical to source (possibly untranslated)
*dmesg* *--console-on**dmesg* *--console-on*
Translation is identical to source (possibly untranslated)
*dmesg* *--console-off**dmesg* *--console-off*
Translation is identical to source (possibly untranslated)
*-c*, *--read-clear**-c*, *--read-clear*
Translation is identical to source (possibly untranslated)
*-D*, *--console-off**-D*, *--console-off*
Translation is identical to source (possibly untranslated)
*-d*, *--show-delta**-d*, *--show-delta*
Translation is identical to source (possibly untranslated)
*-E*, *--console-on**-E*, *--console-on*
Translation is identical to source (possibly untranslated)
*-e*, *--reltime**-e*, *--reltime*
Translation is identical to source (possibly untranslated)
*dmesg --facility=daemon**dmesg --facility=daemon*
Translation is identical to source (possibly untranslated)
*-H*, *--human**-H*, *--human*
Translation is identical to source (possibly untranslated)
*-k*, *--kernel**-k*, *--kernel*
Translation is identical to source (possibly untranslated)
*dmesg --level=err,warn**dmesg --level=err,warn*
Translation is identical to source (possibly untranslated)
*dmesg --level=err+**dmesg --level=err+*
Translation is identical to source (possibly untranslated)
*-P*, *--nopager**-P*, *--nopager*
Translation is identical to source (possibly untranslated)
*-p*, *--force-prefix**-p*, *--force-prefix*
Translation is identical to source (possibly untranslated)
*-S*, *--syslog**-S*, *--syslog*
Translation is identical to source (possibly untranslated)
*-T*, *--ctime**-T*, *--ctime*
Translation is identical to source (possibly untranslated)
*--since* _time_*--since* _time_
Translation is identical to source (possibly untranslated)
*--until* _time_*--until* _time_
Translation is identical to source (possibly untranslated)
*-t*, *--notime**-t*, *--notime*
Translation is identical to source (possibly untranslated)
*-u*, *--userspace**-u*, *--userspace*
Translation is identical to source (possibly untranslated)
*-w*, *--follow**-w*, *--follow*
Translation is identical to source (possibly untranslated)
*-W*, *--follow-new**-W*, *--follow-new*
Translation is identical to source (possibly untranslated)
*-x*, *--decode**-x*, *--decode*
Translation is identical to source (possibly untranslated)
*-a*, **--auto on**|*off**-a*, **--auto on**|*off*
Translation is identical to source (possibly untranslated)
*-c*, *--changerslot* _slot_*-c*, *--changerslot* _slot_
Translation is identical to source (possibly untranslated)
*-d*, *--default**-d*, *--default*
Translation is identical to source (possibly untranslated)
*-F*, *--force**-F*, *--force*
Translation is identical to source (possibly untranslated)
*-f*, *--floppy**-f*, *--floppy*
Translation is identical to source (possibly untranslated)
*-i*, **--manualeject on**|*off**-i*, **--manualeject on**|*off*
Translation is identical to source (possibly untranslated)
*-M*, *--no-partitions-unmount**-M*, *--no-partitions-unmount*
Translation is identical to source (possibly untranslated)
*-m*, *--no-unmount**-m*, *--no-unmount*
Translation is identical to source (possibly untranslated)
*-n*, *--noop**-n*, *--noop*
Translation is identical to source (possibly untranslated)
*-p*, *--proc**-p*, *--proc*
Translation is identical to source (possibly untranslated)
*-q*, *--tape**-q*, *--tape*
Translation is identical to source (possibly untranslated)
*-r*, *--cdrom**-r*, *--cdrom*
Translation is identical to source (possibly untranslated)
*-s*, *--scsi**-s*, *--scsi*
Translation is identical to source (possibly untranslated)
*-T*, *--traytoggle**-T*, *--traytoggle*
Translation is identical to source (possibly untranslated)
*-t*, *--trayclose**-t*, *--trayclose*
Translation is identical to source (possibly untranslated)
*-X*, *--listspeed**-X*, *--listspeed*
Translation is identical to source (possibly untranslated)
*-c*, *--collapse-range**-c*, *--collapse-range*
Translation is identical to source (possibly untranslated)
*-d*, *--dig-holes**-d*, *--dig-holes*
Translation is identical to source (possibly untranslated)
*-r*, *--report-holes**-r*, *--report-holes*
Translation is identical to source (possibly untranslated)
*-i*, *--insert-range**-i*, *--insert-range*
Translation is identical to source (possibly untranslated)
*-n*, *--keep-size**-n*, *--keep-size*
Translation is identical to source (possibly untranslated)
*-p*, *--punch-hole**-p*, *--punch-hole*
Translation is identical to source (possibly untranslated)
*-w*, *--write-zeroes**-w*, *--write-zeroes*
Translation is identical to source (possibly untranslated)
*-x*, *--posix**-x*, *--posix*
Translation is identical to source (possibly untranslated)
*-z*, *--zero-range**-z*, *--zero-range*
Translation is identical to source (possibly untranslated)
*-e*, *-x*, *--exclusive**-e*, *-x*, *--exclusive*
Translation is identical to source (possibly untranslated)
*-n*, *--nb*, *--nonblocking**-n*, *--nb*, *--nonblocking*
Translation is identical to source (possibly untranslated)
*-o*, *--close**-o*, *--close*
Translation is identical to source (possibly untranslated)
*-s*, *--shared**-s*, *--shared*
Translation is identical to source (possibly untranslated)
*-u*, *--unlock**-u*, *--unlock*
Translation is identical to source (possibly untranslated)
*-w*, *--wait*, *--timeout* _seconds_*-w*, *--wait*, *--timeout* _seconds_
Translation is identical to source (possibly untranslated)
*-f*, *--freeze**-f*, *--freeze*
Translation is identical to source (possibly untranslated)
*-u*, *--unfreeze**-u*, *--unfreeze*
Translation is identical to source (possibly untranslated)
*-A, --fstab**-A, --fstab*
Translation is identical to source (possibly untranslated)
*-a, --all**-a, --all*
Translation is identical to source (possibly untranslated)
*-n, --dry-run**-n, --dry-run*
Translation is identical to source (possibly untranslated)
*-o, --offset* _offset_*-o, --offset* _offset_
Translation is identical to source (possibly untranslated)
*--listed-in /etc/fstab:/proc/self/mountinfo*.*--listed-in /etc/fstab:/proc/self/mountinfo*.
Translation is identical to source (possibly untranslated)
*-m, --minimum* _minimum-size_*-m, --minimum* _minimum-size_
Translation is identical to source (possibly untranslated)
*-v, --verbose**-v, --verbose*
Translation is identical to source (possibly untranslated)
*--quiet-unsupported**--quiet-unsupported*
Translation is identical to source (possibly untranslated)
*-a, --adjust**-a, --adjust*
Translation is identical to source (possibly untranslated)
*--getepoch*; *--setepoch**--getepoch*; *--setepoch*
Translation is identical to source (possibly untranslated)
**hwclock --setepoch --epoch=1952****hwclock --setepoch --epoch=1952**
Translation is identical to source (possibly untranslated)
*-r*, *--show*; *--get**-r*, *--show*; *--get*
Translation is identical to source (possibly untranslated)
*-s*, *--hctosys**-s*, *--hctosys*
Translation is identical to source (possibly untranslated)
*-w*, *--systohc**-w*, *--systohc*
Translation is identical to source (possibly untranslated)
*--vl-read*, *--vl-clear**--vl-read*, *--vl-clear*
Translation is identical to source (possibly untranslated)
**--adjfile=**__filename__**--adjfile=**__filename__
Translation is identical to source (possibly untranslated)
*hwclock --set --date='16:45'**hwclock --set --date='16:45'*
Translation is identical to source (possibly untranslated)
*hwclock --predict --date='2525-08-14 07:11:05'**hwclock --predict --date='2525-08-14 07:11:05'*
Translation is identical to source (possibly untranslated)
**--delay=**__seconds__**--delay=**__seconds__
Translation is identical to source (possibly untranslated)
*-D*, *--debug**-D*, *--debug*
Translation is identical to source (possibly untranslated)
**--epoch=**__year__**--epoch=**__year__
Translation is identical to source (possibly untranslated)
*-f*, **--rtc=**__filename__*-f*, **--rtc=**__filename__
Translation is identical to source (possibly untranslated)
*-l*, *--localtime*; *-u*, *--utc**-l*, *--localtime*; *-u*, *--utc*
Translation is identical to source (possibly untranslated)
*--update-drift**--update-drift*
Translation is identical to source (possibly untranslated)
LOCAL vs UTCLOCAL vs UTC
Translation is identical to source (possibly untranslated)
_/usr/share/zoneinfo_, _/usr/share/zoneinfo-posix_, _/usr/share/zoneinfo-leaps__/usr/share/zoneinfo_, _/usr/share/zoneinfo-posix_, _/usr/share/zoneinfo-leaps_
Translation is identical to source (possibly untranslated)
*TZDIR**TZDIR*
Translation is identical to source (possibly untranslated)
_/etc/localtime__/etc/localtime_
Translation is identical to source (possibly untranslated)
_/usr/share/zoneinfo/__/usr/share/zoneinfo/_
Translation is identical to source (possibly untranslated)
*-Q*, *--queue**-Q*, *--queue*
Translation is identical to source (possibly untranslated)
*-q*, *--posix-mqueue**-q*, *--posix-mqueue*
Translation is identical to source (possibly untranslated)
*-s*, *--posix-semaphore**-s*, *--posix-semaphore*
Translation is identical to source (possibly untranslated)
*-M*, *--shmem-key* _shmkey_*-M*, *--shmem-key* _shmkey_
Translation is identical to source (possibly untranslated)
*-m*, *--shmem-id* _shmid_*-m*, *--shmem-id* _shmid_
Translation is identical to source (possibly untranslated)
*-Q*, *--queue-key* _msgkey_*-Q*, *--queue-key* _msgkey_
Translation is identical to source (possibly untranslated)
*-q*, *--queue-id* _msgid_*-q*, *--queue-id* _msgid_
Translation is identical to source (possibly untranslated)
*-S*, *--semaphore-key* _semkey_*-S*, *--semaphore-key* _semkey_
Translation is identical to source (possibly untranslated)
*-s*, *--semaphore-id* _semid_*-s*, *--semaphore-id* _semid_
Translation is identical to source (possibly untranslated)
*-m*, *--shmems**-m*, *--shmems*
Translation is identical to source (possibly untranslated)
*-q*, *--queues**-q*, *--queues*
Translation is identical to source (possibly untranslated)
*-s*, *--semaphores**-s*, *--semaphores*
Translation is identical to source (possibly untranslated)
*-c*, *--creator**-c*, *--creator*
Translation is identical to source (possibly untranslated)
*-l*, *--limits**-l*, *--limits*
Translation is identical to source (possibly untranslated)
*-u*, *--summary**-u*, *--summary*
Translation is identical to source (possibly untranslated)
*-d*, *--delay* _seconds_*-d*, *--delay* _seconds_
Translation is identical to source (possibly untranslated)
*-s*, *--sort* _column_*-s*, *--sort* _column_
Translation is identical to source (possibly untranslated)
*-S*, *--softirq**-S*, *--softirq*
Translation is identical to source (possibly untranslated)
*-t*, *--threshold* _min_*-t*, *--threshold* _min_
Translation is identical to source (possibly untranslated)
*q Q**q Q*
Translation is identical to source (possibly untranslated)
*-1*, *--onestopbit**-1*, *--onestopbit*
Translation is identical to source (possibly untranslated)
*-2*, *--twostopbits**-2*, *--twostopbits*
Translation is identical to source (possibly untranslated)
*-7*, *--sevenbits**-7*, *--sevenbits*
Translation is identical to source (possibly untranslated)
*-8*, *--eightbits**-8*, *--eightbits*
Translation is identical to source (possibly untranslated)
*-e*, *--evenparity**-e*, *--evenparity*
Translation is identical to source (possibly untranslated)
*-n*, *--noparity**-n*, *--noparity*
Translation is identical to source (possibly untranslated)
*-o*, *--oddparity**-o*, *--oddparity*
Translation is identical to source (possibly untranslated)
*losetup* *-c* _loopdev_*losetup* *-c* _loopdev_
Translation is identical to source (possibly untranslated)
*losetup* *-d* _loopdev_ ...*losetup* *-d* _loopdev_ ...
Translation is identical to source (possibly untranslated)
*losetup* *-D**losetup* *-D*
Translation is identical to source (possibly untranslated)
*-d*, *--detach* _loopdev_...*-d*, *--detach* _loopdev_...
Translation is identical to source (possibly untranslated)
*-D*, *--detach-all**-D*, *--detach-all*
Translation is identical to source (possibly untranslated)
*-L*, *--nooverlap**-L*, *--nooverlap*
Translation is identical to source (possibly untranslated)
*-c*, *--set-capacity* _loopdev_*-c*, *--set-capacity* _loopdev_
Translation is identical to source (possibly untranslated)
*-P*, *--partscan**-P*, *--partscan*
Translation is identical to source (possibly untranslated)
*LOOPDEV_DEBUG*=all*LOOPDEV_DEBUG*=all
Translation is identical to source (possibly untranslated)
*-B*, *--bytes**-B*, *--bytes*
Translation is identical to source (possibly untranslated)
*-b*, *--online**-b*, *--online*
Translation is identical to source (possibly untranslated)
*-c*, *--offline**-c*, *--offline*
Translation is identical to source (possibly untranslated)
*-y*, *--physical**-y*, *--physical*
Translation is identical to source (possibly untranslated)
*--arm-model* _id_*--arm-model* _id_
Translation is identical to source (possibly untranslated)
*-g*, *--global**-g*, *--global*
Translation is identical to source (possibly untranslated)
*-M*, *--posix-shmems**-M*, *--posix-shmems*
Translation is identical to source (possibly untranslated)
*-Q*, *--posix-mqueues**-Q*, *--posix-mqueues*
Translation is identical to source (possibly untranslated)
*-S*, *--posix-semaphores**-S*, *--posix-semaphores*
Translation is identical to source (possibly untranslated)
*-P*, *--numeric-perms**-P*, *--numeric-perms*
Translation is identical to source (possibly untranslated)
*RANGE**RANGE*
Translation is identical to source (possibly untranslated)
*SIZE**SIZE*
Translation is identical to source (possibly untranslated)
*STATE**STATE*
Translation is identical to source (possibly untranslated)
*REMOVABLE**REMOVABLE*
Translation is identical to source (possibly untranslated)
*BLOCK**BLOCK*
Translation is identical to source (possibly untranslated)
*NODE**NODE*
Translation is identical to source (possibly untranslated)
*ZONES**ZONES*
Translation is identical to source (possibly untranslated)
*CONFIGURED**CONFIGURED*
Translation is identical to source (possibly untranslated)
*MEMMAP-ON-MEMORY**MEMMAP-ON-MEMORY*
Translation is identical to source (possibly untranslated)
*LSMEM_COLUMNS**LSMEM_COLUMNS*
Translation is identical to source (possibly untranslated)
*-P*, *--persistent**-P*, *--persistent*
Translation is identical to source (possibly untranslated)
*-p*, *--task* _PID_*-p*, *--task* _PID_
Translation is identical to source (possibly untranslated)
*-W*, *--nowrap**-W*, *--nowrap*
Translation is identical to source (possibly untranslated)
*LSNS_DEBUG*=all*LSNS_DEBUG*=all
Translation is identical to source (possibly untranslated)
*mount* _/dir_*mount* _/dir_
Translation is identical to source (possibly untranslated)
*mount --target* _/mountpoint_*mount --target* _/mountpoint_
Translation is identical to source (possibly untranslated)
*mount /dev/foo /dir**mount /dev/foo /dir*
Translation is identical to source (possibly untranslated)
*/dev/cdrom /cd iso9660 ro,user,noauto,unhide**/dev/cdrom /cd iso9660 ro,user,noauto,unhide*
Translation is identical to source (possibly untranslated)
*mount /cd**mount /cd*
Translation is identical to source (possibly untranslated)
*mount --bind* _olddir newdir_*mount --bind* _olddir newdir_
Translation is identical to source (possibly untranslated)
**/**__olddir__ **/**__newdir__ *none bind***/**__olddir__ **/**__newdir__ *none bind*
Translation is identical to source (possibly untranslated)
*mount --bind foo foo**mount --bind foo foo*
Translation is identical to source (possibly untranslated)
*mount --rbind* _olddir newdir_*mount --rbind* _olddir newdir_
Translation is identical to source (possibly untranslated)
*mount -o bind,ro foo foo**mount -o bind,ro foo foo*
Translation is identical to source (possibly untranslated)
*mount -o remount,bind,ro* _olddir newdir_*mount -o remount,bind,ro* _olddir newdir_
Translation is identical to source (possibly untranslated)
*mount --move* _olddir newdir_*mount --move* _olddir newdir_
Translation is identical to source (possibly untranslated)
mount --make-shared mountpoint
mount --make-slave mountpoint
mount --make-private mountpoint
mount --make-unbindable mountpoint
mount --make-shared mountpoint mount --make-slave mountpoint mount --make-private mountpoint mount --make-unbindable mountpoint
Translation is identical to source (possibly untranslated)
mount --make-private --make-unbindable /dev/sda1 /foo
mount --make-private --make-unbindable /dev/sda1 /foo
Translation is identical to source (possibly untranslated)
mount /dev/sda1 /foo
mount --make-private /foo
mount --make-unbindable /foo
mount /dev/sda1 /foo mount --make-private /foo mount --make-unbindable /foo
Translation is identical to source (possibly untranslated)
mount -t btrfs /dev/sdA /mnt
mount --beneath -t xfs /dev/sdB /mnt
umount /mnt
mount -t btrfs /dev/sdA /mnt mount --beneath -t xfs /dev/sdB /mnt umount /mnt
Translation is identical to source (possibly untranslated)
*-B*, *--bind**-B*, *--bind*
Translation is identical to source (possibly untranslated)
*-c*, *--no-canonicalize**-c*, *--no-canonicalize*
Translation is identical to source (possibly untranslated)
*-F*, *--fork**-F*, *--fork*
Translation is identical to source (possibly untranslated)
*-f, --fake**-f, --fake*
Translation is identical to source (possibly untranslated)
*-i, --internal-only**-i, --internal-only*
Translation is identical to source (possibly untranslated)
*-l*, *--show-labels**-l*, *--show-labels*
Translation is identical to source (possibly untranslated)
*-M*, *--move**-M*, *--move*
Translation is identical to source (possibly untranslated)
*--map-groups*, *--map-users* _inner_:_outer_:_count_*--map-groups*, *--map-users* _inner_:_outer_:_count_
Translation is identical to source (possibly untranslated)
*--map-users* /proc/_PID_/ns/user*--map-users* /proc/_PID_/ns/user
Translation is identical to source (possibly untranslated)
*-n*, *--no-mtab**-n*, *--no-mtab*
Translation is identical to source (possibly untranslated)
*-N*, *--namespace* _ns_*-N*, *--namespace* _ns_
Translation is identical to source (possibly untranslated)
*-O*, *--test-opts* _opts_*-O*, *--test-opts* _opts_
Translation is identical to source (possibly untranslated)
*mount -a -O no_netdev**mount -a -O no_netdev*
Translation is identical to source (possibly untranslated)
*mount -a -t ext2 -O _netdev**mount -a -t ext2 -O _netdev*
Translation is identical to source (possibly untranslated)
*-o*, *--options* _opts_*-o*, *--options* _opts_
Translation is identical to source (possibly untranslated)
*mount LABEL=mydisk -o noatime,nodev,nosuid**mount LABEL=mydisk -o noatime,nodev,nosuid*
Translation is identical to source (possibly untranslated)
*--options-source* _source_*--options-source* _source_
Translation is identical to source (possibly untranslated)
*--options-source-force**--options-source-force*
Translation is identical to source (possibly untranslated)
*-R*, *--rbind**-R*, *--rbind*
Translation is identical to source (possibly untranslated)
*-r*, *--ro*, *--read-only**-r*, *--ro*, *--read-only*
Translation is identical to source (possibly untranslated)
*mount --all --target-prefix /chroot -o X-mount.mkdir**mount --all --target-prefix /chroot -o X-mount.mkdir*
Translation is identical to source (possibly untranslated)
*-t*, *--types* _fstype_*-t*, *--types* _fstype_
Translation is identical to source (possibly untranslated)
*mount -a -t nomsdos,smbfs**mount -a -t nomsdos,smbfs*
Translation is identical to source (possibly untranslated)
*-w*, *--rw*, *--read-write**-w*, *--rw*, *--read-write*
Translation is identical to source (possibly untranslated)
findmnt -o TARGET,VFS-OPTIONS,FS-OPTIONS
findmnt -o TARGET,VFS-OPTIONS,FS-OPTIONS
Translation is identical to source (possibly untranslated)
mount -o ro=vfs /dev/sdc1 /Amount -o ro=vfs /dev/sdc1 /A
Translation is identical to source (possibly untranslated)
mount -t tmpfs none /mnt -o \
'context="system_u:object_r:tmp_t:s0:c127,c456",noexec'
mount -t tmpfs none /mnt -o \ 'context="system_u:object_r:tmp_t:s0:c127,c456",noexec'
Translation is identical to source (possibly untranslated)
*mount -o remount,rw /dev/foo /dir**mount -o remount,rw /dev/foo /dir*
Translation is identical to source (possibly untranslated)
*mount -o remount,rw /dir**mount -o remount,rw /dir*
Translation is identical to source (possibly untranslated)
*mount --all -o remount,ro -t vfat**mount --all -o remount,ro -t vfat*
Translation is identical to source (possibly untranslated)
mount -t auto -o'X-mount.auto-fstypes="noext2,ext3"' /dev/sdc1 /mnt/testmount -t auto -o'X-mount.auto-fstypes="noext2,ext3"' /dev/sdc1 /mnt/test
Translation is identical to source (possibly untranslated)
*X-mount.noloop**X-mount.noloop*
Translation is identical to source (possibly untranslated)
**cvf_format=**__module__**cvf_format=**__module__
Translation is identical to source (possibly untranslated)
**cvf_option=**__option__**cvf_option=**__option__
Translation is identical to source (possibly untranslated)
*tz=UTC**tz=UTC*
Translation is identical to source (possibly untranslated)
**time_offset=**__minutes__**time_offset=**__minutes__
Translation is identical to source (possibly untranslated)
**session=**__n__**session=**__n__
Translation is identical to source (possibly untranslated)
**session=**__x__**session=**__x__
Translation is identical to source (possibly untranslated)
**sbsector=**__xxx__**sbsector=**__xxx__
Translation is identical to source (possibly untranslated)
**sys_immutable****sys_immutable**
Translation is identical to source (possibly untranslated)
**hide_dot_files****hide_dot_files**
Translation is identical to source (possibly untranslated)
**windows_names****windows_names**
Translation is identical to source (possibly untranslated)
*hashed_relocation**hashed_relocation*
Translation is identical to source (possibly untranslated)
*no_unhashed_relocation**no_unhashed_relocation*
Translation is identical to source (possibly untranslated)
*ubiX_Y**ubiX_Y*
Translation is identical to source (possibly untranslated)
*ubiY**ubiY*
Translation is identical to source (possibly untranslated)
*ubiX:NAME**ubiX:NAME*
Translation is identical to source (possibly untranslated)
*ubi:NAME**ubi:NAME*
Translation is identical to source (possibly untranslated)
*no_chk_data_crc**no_chk_data_crc*
Translation is identical to source (possibly untranslated)
**verity.roothash=**__hex__**verity.roothash=**__hex__
Translation is identical to source (possibly untranslated)
**verity.hashoffset=**__offset__**verity.hashoffset=**__offset__
Translation is identical to source (possibly untranslated)
**verity.fecoffset=**__offset__**verity.fecoffset=**__offset__
Translation is identical to source (possibly untranslated)
*mount /tmp/disk.img /mnt -t vfat -o loop=/dev/loop3**mount /tmp/disk.img /mnt -t vfat -o loop=/dev/loop3*
Translation is identical to source (possibly untranslated)
*mount /tmp/disk.img /mnt -o loop**mount /tmp/disk.img /mnt -o loop*
Translation is identical to source (possibly untranslated)
*mount /tmp/disk.img /mnt**mount /tmp/disk.img /mnt*
Translation is identical to source (possibly untranslated)
*mount -t ext4 /tmp/disk.img /mnt**mount -t ext4 /tmp/disk.img /mnt*
Translation is identical to source (possibly untranslated)
_/etc/filesystems__/etc/filesystems_
Translation is identical to source (possibly untranslated)
*-d*, *--fs-devno**-d*, *--fs-devno*
Translation is identical to source (possibly untranslated)
*-x*, *--devno**-x*, *--devno*
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/mnt__/proc/pid/ns/mnt_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/uts__/proc/pid/ns/uts_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/ipc__/proc/pid/ns/ipc_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/net__/proc/pid/ns/net_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/pid__/proc/pid/ns/pid_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/user__/proc/pid/ns/user_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/cgroup__/proc/pid/ns/cgroup_
Translation is identical to source (possibly untranslated)
_/proc/pid/ns/time__/proc/pid/ns/time_
Translation is identical to source (possibly untranslated)
_/proc/pid/root__/proc/pid/root_
Translation is identical to source (possibly untranslated)
*-N*, *--net-socket* _fd_*-N*, *--net-socket* _fd_
Translation is identical to source (possibly untranslated)
*-G*, *--setgid* _gid_*-G*, *--setgid* _gid_
Translation is identical to source (possibly untranslated)
*-S*, *--setuid* _uid_*-S*, *--setuid* _uid_
Translation is identical to source (possibly untranslated)
*--preserve-credentials**--preserve-credentials*
Translation is identical to source (possibly untranslated)
*-e*, *--env**-e*, *--env*
Translation is identical to source (possibly untranslated)
*-Z*, *--follow-context**-Z*, *--follow-context*
Translation is identical to source (possibly untranslated)
*-c*, *--join-cgroup**-c*, *--join-cgroup*
Translation is identical to source (possibly untranslated)
*pivot_root* _new_root_ _put_old_*pivot_root* _new_root_ _put_old_
Translation is identical to source (possibly untranslated)
cd new_root
pivot_root . put_old
exec chroot . command
cd new_root pivot_root . put_old exec chroot . command
Translation is identical to source (possibly untranslated)
*-p*, *--pid* _PID_*-p*, *--pid* _PID_
Translation is identical to source (possibly untranslated)
*prlimit --pid 13134**prlimit --pid 13134*
Translation is identical to source (possibly untranslated)
*prlimit --pid 13134 --rss --nofile=1024:4095**prlimit --pid 13134 --rss --nofile=1024:4095*
Translation is identical to source (possibly untranslated)
*prlimit --pid 13134 --nproc=512:**prlimit --pid 13134 --nproc=512:*
Translation is identical to source (possibly untranslated)
*prlimit --cpu=10 sort -u hugefile**prlimit --cpu=10 sort -u hugefile*
Translation is identical to source (possibly untranslated)
*-b*, *--histbin**-b*, *--histbin*
Translation is identical to source (possibly untranslated)
*-m*, *--mapfile* _mapfile_*-m*, *--mapfile* _mapfile_
Translation is identical to source (possibly untranslated)
*-n*, *--no-auto**-n*, *--no-auto*
Translation is identical to source (possibly untranslated)
*-M*, *--multiplier* _multiplier_*-M*, *--multiplier* _multiplier_
Translation is identical to source (possibly untranslated)
*-p*, *--profile* _pro-file_*-p*, *--profile* _pro-file_
Translation is identical to source (possibly untranslated)
*-r*, *--reset**-r*, *--reset*
Translation is identical to source (possibly untranslated)
*-s, --counters**-s, --counters*
Translation is identical to source (possibly untranslated)
_/usr/src/linux/System.map__/usr/src/linux/System.map_
Translation is identical to source (possibly untranslated)
_/usr/src/linux/*__/usr/src/linux/*_
Translation is identical to source (possibly untranslated)
readprofile | grep _ext2
readprofile | grep _ext2
Translation is identical to source (possibly untranslated)
readprofile -av | less
readprofile -av | less
Translation is identical to source (possibly untranslated)
readprofile -p ~/profile.freeze -m /zImage.map.gz
readprofile -p ~/profile.freeze -m /zImage.map.gz
Translation is identical to source (possibly untranslated)
sudo readprofile -M 20
sudo readprofile -M 20
Translation is identical to source (possibly untranslated)
*--priority* _priority_*--priority* _priority_
Translation is identical to source (possibly untranslated)
*--relative* _delta_*--relative* _delta_
Translation is identical to source (possibly untranslated)
*-g*, *--pgrp**-g*, *--pgrp*
Translation is identical to source (possibly untranslated)
*-u*, *--user**-u*, *--user*
Translation is identical to source (possibly untranslated)
*renice +1 987 -u daemon root -p 32**renice +1 987 -u daemon root -p 32*
Translation is identical to source (possibly untranslated)
rfkill --output ID,TYPE
rfkill block all
rfkill unblock wlan
rfkill block bluetooth uwb wimax wwan gps fm nfc
rfkill --output ID,TYPE rfkill block all rfkill unblock wlan rfkill block bluetooth uwb wimax wwan gps fm nfc
Translation is identical to source (possibly untranslated)
*--date* _timestamp_*--date* _timestamp_
Translation is identical to source (possibly untranslated)
*-l*, *--local**-l*, *--local*
Translation is identical to source (possibly untranslated)
*-s*, *--seconds* _seconds_*-s*, *--seconds* _seconds_
Translation is identical to source (possibly untranslated)
*-t*, *--time* _time_t_*-t*, *--time* _time_t_
Translation is identical to source (possibly untranslated)
*-u*, *--utc**-u*, *--utc*
Translation is identical to source (possibly untranslated)
*-p*, **--pid=**_pid_*-p*, **--pid=**_pid_
Translation is identical to source (possibly untranslated)
*-F*, *--fdpic-funcptrs**-F*, *--fdpic-funcptrs*
Translation is identical to source (possibly untranslated)
*-I*, *--short-inode**-I*, *--short-inode*
Translation is identical to source (possibly untranslated)
*-L*, *--addr-compat-layout**-L*, *--addr-compat-layout*
Translation is identical to source (possibly untranslated)
*-R*, *--addr-no-randomize**-R*, *--addr-no-randomize*
Translation is identical to source (possibly untranslated)
*-S*, *--whole-seconds**-S*, *--whole-seconds*
Translation is identical to source (possibly untranslated)
*-T*, *--sticky-timeouts**-T*, *--sticky-timeouts*
Translation is identical to source (possibly untranslated)
*-X*, *--read-implies-exec**-X*, *--read-implies-exec*
Translation is identical to source (possibly untranslated)
*-Z*, *--mmap-page-zero**-Z*, *--mmap-page-zero*
Translation is identical to source (possibly untranslated)
*-f*, *--foreground**-f*, *--foreground*
Translation is identical to source (possibly untranslated)
*--clear-groups**--clear-groups*
Translation is identical to source (possibly untranslated)
*-d*, *--dump**-d*, *--dump*
Translation is identical to source (possibly untranslated)
*--nnp*, *--no-new-privs**--nnp*, *--no-new-privs*
Translation is identical to source (possibly untranslated)
*--rgid* _gid_, *--egid* _gid_, *--regid* _gid_*--rgid* _gid_, *--egid* _gid_, *--regid* _gid_
Translation is identical to source (possibly untranslated)
*--ruid* _uid_, *--euid* _uid_, *--reuid* _uid_*--ruid* _uid_, *--euid* _uid_, *--reuid* _uid_
Translation is identical to source (possibly untranslated)
*--apparmor-profile* _profile_*--apparmor-profile* _profile_
Translation is identical to source (possibly untranslated)
*--landlock-access* _access_*--landlock-access* _access_
Translation is identical to source (possibly untranslated)
*setpriv --landlock-access fs**setpriv --landlock-access fs*
Translation is identical to source (possibly untranslated)
*setpriv --landlock-access fs:remove-file,make-dir**setpriv --landlock-access fs:remove-file,make-dir*
Translation is identical to source (possibly untranslated)
*--landlock-rule* _rule_*--landlock-rule* _rule_
Translation is identical to source (possibly untranslated)
*--landlock-rule path-beneath:read-file:/boot**--landlock-rule path-beneath:read-file:/boot*
Translation is identical to source (possibly untranslated)
*-c*, *--ctty**-c*, *--ctty*
Translation is identical to source (possibly untranslated)
*-f*, *--fork**-f*, *--fork*
Translation is identical to source (possibly untranslated)
*-w*, *--wait**-w*, *--wait*
Translation is identical to source (possibly untranslated)
*--discard=once**--discard=once*
Translation is identical to source (possibly untranslated)
*--discard=pages**--discard=pages*
Translation is identical to source (possibly untranslated)
*-e*, *--ifexists**-e*, *--ifexists*
Translation is identical to source (possibly untranslated)
*-f*, *--fixpgsz**-f*, *--fixpgsz*
Translation is identical to source (possibly untranslated)
*-s*, *--summary**-s*, *--summary*
Translation is identical to source (possibly untranslated)
*-U* _uuid_*-U* _uuid_
Translation is identical to source (possibly untranslated)
*-i*, *--irq* _argument_*-i*, *--irq* _argument_
Translation is identical to source (possibly untranslated)
*-c*, *--chars* _characters_*-c*, *--chars* _characters_
Translation is identical to source (possibly untranslated)
*-s*, *--status**-s*, *--status*
Translation is identical to source (possibly untranslated)
_/dev/lp?_, _/proc/parport/*/*__/dev/lp?_, _/proc/parport/*/*_
Translation is identical to source (possibly untranslated)
*-C* requires a Linux version prior to 2.1.131.*-C* requires a Linux version prior to 2.1.131.
Translation is identical to source (possibly untranslated)
*umount* *-h*|*-V**umount* *-h*|*-V*
Translation is identical to source (possibly untranslated)
*-A*, *--all-targets**-A*, *--all-targets*
Translation is identical to source (possibly untranslated)
*-d*, *--detach-loop**-d*, *--detach-loop*
Translation is identical to source (possibly untranslated)
*-i*, *--internal-only**-i*, *--internal-only*
Translation is identical to source (possibly untranslated)
*-l*, *--lazy**-l*, *--lazy*
Translation is identical to source (possibly untranslated)
*-O*, *--test-opts* _option_...*-O*, *--test-opts* _option_...
Translation is identical to source (possibly untranslated)
*umount.fuse -t fuse.sshfs**umount.fuse -t fuse.sshfs*
Translation is identical to source (possibly untranslated)
_/proc/self/mountinfo__/proc/self/mountinfo_
Translation is identical to source (possibly untranslated)
*--forward-signals**--forward-signals*
Translation is identical to source (possibly untranslated)
*-r*, *--map-root-user**-r*, *--map-root-user*
Translation is identical to source (possibly untranslated)
*-c*, *--map-current-user**-c*, *--map-current-user*
Translation is identical to source (possibly untranslated)
*--owner* __uid__**:**__gid__*--owner* __uid__**:**__gid__
Translation is identical to source (possibly untranslated)
*--setgroups* **allow**|**deny***--setgroups* **allow**|**deny**
Translation is identical to source (possibly untranslated)
*-R*, *--root* __dir__*-R*, *--root* __dir__
Translation is identical to source (possibly untranslated)
*-w*, *--wd* __dir__*-w*, *--wd* __dir__
Translation is identical to source (possibly untranslated)
*--monotonic* _offset_*--monotonic* _offset_
Translation is identical to source (possibly untranslated)
*--boottime* _offset_*--boottime* _offset_
Translation is identical to source (possibly untranslated)
# unshare --fork --pid --mount-proc readlink /proc/self
1
# unshare --fork --pid --mount-proc readlink /proc/self 1
Translation is identical to source (possibly untranslated)
``\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\x00\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xfe\\xff\\xff````\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\x00\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xff\\xfe\\xff\\xff``
Translation is identical to source (possibly untranslated)
``/bin/qemu-ppc-static````/bin/qemu-ppc-static``
Translation is identical to source (possibly untranslated)
``OCF````OCF``
Translation is identical to source (possibly untranslated)
*-F*, *--noflags**-F*, *--noflags*
Translation is identical to source (possibly untranslated)
*-I*, *--noident**-I*, *--noident*
Translation is identical to source (possibly untranslated)
*-O*, *--oneline**-O*, *--oneline*
Translation is identical to source (possibly untranslated)
*-p*, *--setpretimeout* _seconds_*-p*, *--setpretimeout* _seconds_
Translation is identical to source (possibly untranslated)
*-s*, *--settimeout* _seconds_*-s*, *--settimeout* _seconds_
Translation is identical to source (possibly untranslated)
*-T*, *--notimeouts**-T*, *--notimeouts*
Translation is identical to source (possibly untranslated)
*-x*, *--flags-only**-x*, *--flags-only*
Translation is identical to source (possibly untranslated)
*zramctl* *-r* _zramdev_...*zramctl* *-r* _zramdev_...
Translation is identical to source (possibly untranslated)
*zramctl* *-f**zramctl* *-f*
Translation is identical to source (possibly untranslated)
*-f*, *--find**-f*, *--find*
Translation is identical to source (possibly untranslated)
*-p*, *--algorithm-params* _parameter_...*-p*, *--algorithm-params* _parameter_...
Translation is identical to source (possibly untranslated)
*-a*, *--autologin* _username_*-a*, *--autologin* _username_
Translation is identical to source (possibly untranslated)
*-c*, *--noreset**-c*, *--noreset*
Translation is identical to source (possibly untranslated)
*-E*, *--remote**-E*, *--remote*
Translation is identical to source (possibly untranslated)
*-h, --flow-control**-h, --flow-control*
Translation is identical to source (possibly untranslated)
*-H*, *--host* _fakehost_*-H*, *--host* _fakehost_
Translation is identical to source (possibly untranslated)
*-i*, *--noissue**-i*, *--noissue*
Translation is identical to source (possibly untranslated)
*-I*, *--init-string* _initstring_*-I*, *--init-string* _initstring_
Translation is identical to source (possibly untranslated)
*-J*, *--noclear**-J*, *--noclear*
Translation is identical to source (possibly untranslated)
*-l*, *--login-program* _login_program_*-l*, *--login-program* _login_program_
Translation is identical to source (possibly untranslated)
*-m*, *--extract-baud**-m*, *--extract-baud*
Translation is identical to source (possibly untranslated)
*-n*, *--skip-login**-n*, *--skip-login*
Translation is identical to source (possibly untranslated)
*-N*, *--nonewline**-N*, *--nonewline*
Translation is identical to source (possibly untranslated)
*-o*, *--login-options* _login_options_*-o*, *--login-options* _login_options_
Translation is identical to source (possibly untranslated)
*--login-options '-h darkstar \-- \u'**--login-options '-h darkstar \-- \u'*
Translation is identical to source (possibly untranslated)
*-p*, *--login-pause**-p*, *--login-pause*
Translation is identical to source (possibly untranslated)
*-R*, *--hangup**-R*, *--hangup*
Translation is identical to source (possibly untranslated)
*-s*, *--keep-baud**-s*, *--keep-baud*
Translation is identical to source (possibly untranslated)
*-U*, *--detect-case**-U*, *--detect-case*
Translation is identical to source (possibly untranslated)
*-w*, *--wait-cr**-w*, *--wait-cr*
Translation is identical to source (possibly untranslated)
*--long-hostname**--long-hostname*
Translation is identical to source (possibly untranslated)
*/sbin/agetty 9600 ttyS1**/sbin/agetty 9600 ttyS1*
Translation is identical to source (possibly untranslated)
*/sbin/agetty --local-line 9600 ttyS1 vt100**/sbin/agetty --local-line 9600 ttyS1 vt100*
Translation is identical to source (possibly untranslated)
*/sbin/agetty --extract-baud --timeout 60 ttyS1 9600,2400,1200**/sbin/agetty --extract-baud --timeout 60 ttyS1 9600,2400,1200*
Translation is identical to source (possibly untranslated)
*/sbin/agetty --wait-cr --init-string 'ATE0Q1&D2&C1S0=1\015' 115200 ttyS1**/sbin/agetty --wait-cr --init-string 'ATE0Q1&D2&C1S0=1\015' 115200 ttyS1*
Translation is identical to source (possibly untranslated)
_/etc/os-release /usr/lib/os-release__/etc/os-release /usr/lib/os-release_
Translation is identical to source (possibly untranslated)
*-e*, *--return**-e*, *--return*
Translation is identical to source (possibly untranslated)
*-f*, *--flush**-f*, *--flush*
Translation is identical to source (possibly untranslated)
*-m*, *--logging-format* _format_*-m*, *--logging-format* _format_
Translation is identical to source (possibly untranslated)
*SHELL**SHELL*
Translation is identical to source (possibly untranslated)
if test -t 0 ; then
script
exit
fi
if test -t 0 ; then
script
exit
fi
Translation is identical to source (possibly untranslated)
*--appcursorkeys* **on**|**off***--appcursorkeys* **on**|**off**
Translation is identical to source (possibly untranslated)
*--background* __8-color__|**default***--background* __8-color__|**default**
Translation is identical to source (possibly untranslated)
*--blink* **on**|**off***--blink* **on**|**off**
Translation is identical to source (possibly untranslated)
*--bold* **on**|**off***--bold* **on**|**off**
Translation is identical to source (possibly untranslated)
*--cursor* **on**|**off***--cursor* **on**|**off**
Translation is identical to source (possibly untranslated)
*--file* _filename_*--file* _filename_
Translation is identical to source (possibly untranslated)
*--foreground* __8-color__|**default***--foreground* __8-color__|**default**
Translation is identical to source (possibly untranslated)
*--half-bright* **on**|**off***--half-bright* **on**|**off**
Translation is identical to source (possibly untranslated)
*--hbcolor* _16-color_*--hbcolor* _16-color_
Translation is identical to source (possibly untranslated)
*--inversescreen* **on**|**off***--inversescreen* **on**|**off**
Translation is identical to source (possibly untranslated)
*--linewrap* **on**|**off***--linewrap* **on**|**off**
Translation is identical to source (possibly untranslated)
*--msg* **on**|**off***--msg* **on**|**off**
Translation is identical to source (possibly untranslated)
*--msglevel* **0**-**8***--msglevel* **0**-**8**
Translation is identical to source (possibly untranslated)
*--repeat* **on**|**off***--repeat* **on**|**off**
Translation is identical to source (possibly untranslated)
*--reverse* **on**|**off***--reverse* **on**|**off**
Translation is identical to source (possibly untranslated)
*--ulcolor* _16-color_*--ulcolor* _16-color_
Translation is identical to source (possibly untranslated)
*--underline* **on**|**off***--underline* **on**|**off**
Translation is identical to source (possibly untranslated)
*-n*, *--nobanner**-n*, *--nobanner*
Translation is identical to source (possibly untranslated)
*col* _options_*col* _options_
Translation is identical to source (possibly untranslated)
*-b*, *--no-backspaces**-b*, *--no-backspaces*
Translation is identical to source (possibly untranslated)
*-f*, *--fine**-f*, *--fine*
Translation is identical to source (possibly untranslated)
*-h*, *--tabs**-h*, *--tabs*
Translation is identical to source (possibly untranslated)
*-p*, *--pass**-p*, *--pass*
Translation is identical to source (possibly untranslated)
*-x*, *--spaces**-x*, *--spaces*
Translation is identical to source (possibly untranslated)
*-H*, *--help**-H*, *--help*
Translation is identical to source (possibly untranslated)
*ESC-7**ESC-7*
Translation is identical to source (possibly untranslated)
*ESC-8**ESC-8*
Translation is identical to source (possibly untranslated)
*ESC-9**ESC-9*
Translation is identical to source (possibly untranslated)
*-*, *--no-underlining**-*, *--no-underlining*
Translation is identical to source (possibly untranslated)
*-2*, *--half-lines**-2*, *--half-lines*
Translation is identical to source (possibly untranslated)
*-J, --json**-J, --json*
Translation is identical to source (possibly untranslated)
*-c, --output-width* _width_*-c, --output-width* _width_
Translation is identical to source (possibly untranslated)
*-d, --table-noheadings**-d, --table-noheadings*
Translation is identical to source (possibly untranslated)
*-t, --table**-t, --table*
Translation is identical to source (possibly untranslated)
*-C, --table-column* _attributes_*-C, --table-column* _attributes_
Translation is identical to source (possibly untranslated)
*-N, --table-columns* _names_*-N, --table-columns* _names_
Translation is identical to source (possibly untranslated)
*-e, --table-header-repeat**-e, --table-header-repeat*
Translation is identical to source (possibly untranslated)
*-K, --table-header-as-columns**-K, --table-header-as-columns*
Translation is identical to source (possibly untranslated)
*-m, --table-maxout**-m, --table-maxout*
Translation is identical to source (possibly untranslated)
*-L, --keep-empty-lines**-L, --keep-empty-lines*
Translation is identical to source (possibly untranslated)
*-r, --tree* _column_*-r, --tree* _column_
Translation is identical to source (possibly untranslated)
*-i, --tree-id* _column_*-i, --tree-id* _column_
Translation is identical to source (possibly untranslated)
*-p, --tree-parent* _column_*-p, --tree-parent* _column_
Translation is identical to source (possibly untranslated)
*-x, --fillrows**-x, --fillrows*
Translation is identical to source (possibly untranslated)
*COLUMNS**COLUMNS*
Translation is identical to source (possibly untranslated)
printf "a:b:c\n1::3\n" | column -t -s ':'
printf "a:b:c\n1::3\n" | column -t -s ':'
Translation is identical to source (possibly untranslated)
*-b*, *--one-byte-octal**-b*, *--one-byte-octal*
Translation is identical to source (possibly untranslated)
*-X*, *--one-byte-hex**-X*, *--one-byte-hex*
Translation is identical to source (possibly untranslated)
*-c*, *--one-byte-char**-c*, *--one-byte-char*
Translation is identical to source (possibly untranslated)
*-C*, *--canonical**-C*, *--canonical*
Translation is identical to source (possibly untranslated)
*-d*, *--two-bytes-decimal**-d*, *--two-bytes-decimal*
Translation is identical to source (possibly untranslated)
*-o*, *--two-bytes-octal**-o*, *--two-bytes-octal*
Translation is identical to source (possibly untranslated)
*-s*, *--skip* _offset_*-s*, *--skip* _offset_
Translation is identical to source (possibly untranslated)
*-v*, *--no-squeezing**-v*, *--no-squeezing*
Translation is identical to source (possibly untranslated)
*-x*, *--two-bytes-hex**-x*, *--two-bytes-hex*
Translation is identical to source (possibly untranslated)
*COLOR**COLOR*
Translation is identical to source (possibly untranslated)
*OFFSET**OFFSET*
Translation is identical to source (possibly untranslated)
*-d*, *--silent**-d*, *--silent*
Translation is identical to source (possibly untranslated)
*-l*, *--logical**-l*, *--logical*
Translation is identical to source (possibly untranslated)
*-e*, *--exit-on-eof**-e*, *--exit-on-eof*
Translation is identical to source (possibly untranslated)
*-f*, *--no-pause**-f*, *--no-pause*
Translation is identical to source (possibly untranslated)
*-p*, *--print-over**-p*, *--print-over*
Translation is identical to source (possibly untranslated)
*-c*, *--clean-print**-c*, *--clean-print*
Translation is identical to source (possibly untranslated)
*-s*, *--squeeze**-s*, *--squeeze*
Translation is identical to source (possibly untranslated)
*-u*, *--plain**-u*, *--plain*
Translation is identical to source (possibly untranslated)
*RETURN**RETURN*
Translation is identical to source (possibly untranslated)
*MORE**MORE*
Translation is identical to source (possibly untranslated)
*TERM**TERM*
Translation is identical to source (possibly untranslated)
*VISUAL**VISUAL*
Translation is identical to source (possibly untranslated)
*MORESECURE**MORESECURE*
Translation is identical to source (possibly untranslated)
*PAGERSECURE**PAGERSECURE*
Translation is identical to source (possibly untranslated)
*MORE_SHELL_LINES**MORE_SHELL_LINES*
Translation is identical to source (possibly untranslated)
Eric Shienbrood, UC Berkeley.Eric Shienbrood, UC Berkeley.
Translation is identical to source (possibly untranslated)
**+/**__pattern__*/***+/**__pattern__*/*
Translation is identical to source (possibly untranslated)
__i__**/**__pattern__**/**__i__**/**__pattern__**/**
Translation is identical to source (possibly untranslated)
*LANG*, *LC_ALL*, *LC_COLLATE*, *LC_CTYPE*, *LC_MESSAGES**LANG*, *LC_ALL*, *LC_COLLATE*, *LC_CTYPE*, *LC_MESSAGES*
Translation is identical to source (possibly untranslated)
*LINES**LINES*
Translation is identical to source (possibly untranslated)
*-i*, *--indicated**-i*, *--indicated*
Translation is identical to source (possibly untranslated)
*-t*, *-T*, *--terminal* _terminal_*-t*, *-T*, *--terminal* _terminal_
Translation is identical to source (possibly untranslated)
*-b*, *--binary**-b*, *--binary*
Translation is identical to source (possibly untranslated)
*-g*, *--grouped-mask**-g*, *--grouped-mask*
Translation is identical to source (possibly untranslated)
*-m*, *--mask**-m*, *--mask*
Translation is identical to source (possibly untranslated)
*PAM_SUCCESS**PAM_SUCCESS*
Translation is identical to source (possibly untranslated)
*PAM_SERVICE_ERR**PAM_SERVICE_ERR*
Translation is identical to source (possibly untranslated)
*PAM_USER_UNKNOWN**PAM_USER_UNKNOWN*
Translation is identical to source (possibly untranslated)
*PAM_IGNORE**PAM_IGNORE*
terminology · 4 träffar
Swedish terminology: prefer 'rad' over 'linje' in CLI/programming context
The default line discipline, providing transparent operation (raw mode) as well as the habitual terminal line editing capabilities (cooked mode).Den förinställda linjedisciplinen ger transparent drift (raw mode) samt terminalens vanliga möjligheter att redigera linjer (cooked mode).
Swedish terminology: prefer 'rad' over 'linje' in CLI/programming context
Forces the line to be a local line with no need for carrier detect. This can be useful when you have a locally attached terminal where the serial line does not set the carrier-detect signal.Tvingar linjen att vara en lokal linje utan behov av bärvågsdetektering. Detta kan vara användbart när du har en lokalt ansluten terminal där den seriella linjen inte ställer in signalen för bärvågsdetektering.
Swedish terminology: prefer 'rad' over 'linje' in CLI/programming context
For a hardwired line or a console tty:För en kabelansluten linje eller en konsol-tty:
Swedish terminology: prefer 'rad' over 'linje' in CLI/programming context
Makes the terminal continue on a new line when a line is full.Gör att terminalen fortsätter på en ny linje när en linje är full.
url-preservation · 4 träffar
URLs missing in translation: ['https://github.com/util-linux/util-linux/issues[issue']
For bug reports, use the https://github.com/util-linux/util-linux/issues[issue tracker].För felrapporter, använd https://github.com/util-linux/util-linux/issues[felhanteraren].
URLs missing in translation: ['https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=134fca9063ad4851de767d1768180e5dede9a881[kernel']
*fincore* counts pages of file contents being resident in memory (in core), and reports the numbers. If an error occurs during counting, then an error message is printed to the stderr and *fincore* continues processing the rest of files listed in a command line. *fincore* uses the *cachestat*(2) syscall to count resident pages. If the *cachestat*(2) syscall is not available and *cachestat* usage is not forced with the *--cachestat* option, then *fincore* uses the *mincore*(2) syscall as a fallback. The *cachestat*(2) syscall is more efficient than *mincore* because it does not require a page table lock to walks page tables, and also reports more information than *mincore*, like the number of cached pages, dirty pages, pages marked for writeback, evicted pages, and recently evicted pages. Another difference between the two syscalls is that if write permissions are not granted to the file, then *cachestat*(2) returns an error, while *mincore*(2) for security reasons, returns fake data as if all pages were resident in memory (c.f.r. link:https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=134fca9063ad4851de767d1768180e5dede9a881[kernel commit "make mincore() more conservative"]).*fincore* räknar de sidor av filinnehåll som finns i minnet och rapporterar antalet. Om ett fel uppstår under räkningen skrivs ett felmeddelande till standard fel och *fincore* fortsätter att bearbeta resten av filerna som anges på kommandoraden. *fincore* använder systemanropet *cachestat*(2) för att räkna sidor i minnet. Om *cachestat*(2) inte är tillgängligt och användningen av *cachestat* inte framtvingas med flaggan *--cachestat*, använder *fincore* systemanropet *mincore*(2) som reserv. Systemanropet *cachestat*(2) är effektivare än *mincore* eftersom det inte behöver låsa sidtabeller för att gå igenom dem. Det rapporterar också mer information än *mincore*, såsom antal cachade sidor, ändrade sidor, sidor markerade för återskrivning, undanträngda sidor och nyligen undanträngda sidor. En annan skillnad mellan anropen är att om skrivbehörighet till filen saknas returnerar *cachestat*(2) ett fel, medan *mincore*(2) av säkerhetsskäl returnerar falska data som om alla sidor fanns i minnet (jämför link:https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=134fca9063ad4851de767d1768180e5dede9a881[kärnändringen "make mincore() more conservative"]).
URLs missing in translation: ['https://docs.kernel.org/driver-api/rfkill.html[Linux']
*powertop*(8), *systemd-rfkill*(8), https://docs.kernel.org/driver-api/rfkill.html[Linux kernel documentation]*powertop*(8), *systemd-rfkill*(8), https://docs.kernel.org/driver-api/rfkill.html[Dokumentation om Linux-kärnan]
URLs missing in translation: ['https://docs.kernel.org/admin-guide/blockdev/zram.html[Linux']
link:https://docs.kernel.org/admin-guide/blockdev/zram.html[Linux kernel documentation]länk:https://docs.kernel.org/admin-guide/blockdev/zram.html[Dokumentation om Linux-kärnan]
xml-tags-mismatch · 8 träffar
XML/HTML tags mismatch: source has [], translation has ['<tp>']
Report man page translation bugs to: <%1>Rapportera översättningsfel för manualsidor till: <%1> Har du synpunkter på översättning, kontakta <tp-sv@listor.tp-sv.se>
XML/HTML tags mismatch: source has ['<name>', '<value>'], translation has ['<namn>']
*<name>: <value>**<namn>: <värde>*
XML/HTML tags mismatch: source has ['<number>'], translation has ['<nummer>']
The week number requested by the --week=<number> command line option.Det veckonummer som begärs med kommandoradsflaggan --week=<nummer>.
XML/HTML tags mismatch: source has ['<size>', '<size>', '<size>'], translation has ['<storlek>']
Specify _SIZE_ as <size>[m|M|g|G]. With m or M, <size> specifies the memory size in MiB (1024 x 1024 bytes). With g or G, <size> specifies the memory size in GiB (1024 x 1024 x 1024 bytes). The default unit is MiB.Ange _STORLEK_ som <storlek>[m|M|g|G]. Med m eller M anges minnesstorleken i MiB (1024 x 1024 byte). Med g eller G anges minnesstorleken i GiB (1024 x 1024 x 1024 byte). Standardenheten är MiB.
XML/HTML tags mismatch: source has ['<end>', '<end>', '<start>', '<start>'], translation has ['<slut>', '<slut>', '<start>', '<start>']
Specify _RANGE_ in the form 0x<start>-0x<end> as shown in the output of the *lsmem*(1) command. <start> is the hexadecimal address of the first byte and <end> is the hexadecimal address of the last byte in the memory range.Ange _INTERVALL_ i formen 0x<start>-0x<slut> som visas i utdata från kommandot *lsmem*(1). <start> är den hexadecimala adressen för första byten och <slut> är den hexadecimala adressen för sista byten i minnesintervallet.
XML/HTML tags mismatch: source has ['<block>', '<first>', '<first>', '<last>', '<last>'], translation has ['<block>', '<sista>', '<sista>']
Specify _BLOCKRANGE_ in the form <first>-<last> or <block> as shown in the output of the *lsmem*(1) command. <first> is the number of the first memory block and <last> is the number of the last memory block in the memory range. Alternatively a single block can be specified. _BLOCKRANGE_ requires the *--blocks* option.Ange _BLOCKINTERVALL_ i formen <första>-<sista> eller <block> som visas i utdata från kommandot *lsmem*(1). <första> är numret på första minnesblocket och <sista> är numret på sista minnesblocket i intervallet. Ett enskilt block kan också anges. _BLOCKINTERVALL_ kräver flaggan *--blocks*.
XML/HTML tags mismatch: source has ['<file>', '<services>'], translation has ['<fil>']
*pam_lastlog2.so* [debug] [silent] [silent_if=<services>] [database=<file>]*pam_lastlog2.so* [debug] [silent] [silent_if=<tjänster>] [database=<fil>]
XML/HTML tags mismatch: source has ['<file>'], translation has ['<fil>']
*database=<file>**database=<fil>*
Källfil och spårbarhet
- Version
- 2.42-rc2
- SHA-256 original
0a463ffc60a7b55f486f5ea7e30fa623270851c3aafe751d7ebded8cb2aa8b22- Teckenkodning
- UTF-8
- Hämtad
- 2026-09-17